# -*- rpm-spec -*-

# If neither fedora nor rhel was defined, try to guess them from %{dist}
%if !0%{?rhel} && !0%{?fedora}
%{expand:%(echo "%{?dist}" | \
  sed -ne 's/^\.el\([0-9]\+\).*/%%define rhel \1/p')}
%{expand:%(echo "%{?dist}" | \
  sed -ne 's/^\.fc\?\([0-9]\+\).*/%%define fedora \1/p')}
%endif

# Default to skipping autoreconf.  Distros can change just this one line
# (or provide a command-line override) if they backport any patches that
# touch configure.ac or Makefile.am.
%{!?enable_autotools:%define enable_autotools 1}

# A client only build will create a libvirt.so only containing
# the generic RPC driver, and test driver and no libvirtd
# Default to a full server + client build
%define client_only        0

# Now turn off server build in certain cases

# RHEL-5 builds are client-only for s390, ppc
%if 0%{?rhel} == 5
%ifnarch i386 i586 i686 x86_64 ia64
%define client_only        1
%endif
%endif

# Disable all server side drivers if client only build requested
%if %{client_only}
%define server_drivers     0
%else
%define server_drivers     1
%endif


# Now set the defaults for all the important features, independent
# of any particular OS

# First the daemon itself
%define with_libvirtd      0%{!?_without_libvirtd:%{server_drivers}}
%define with_avahi         0%{!?_without_avahi:%{server_drivers}}

# Then the hypervisor drivers that run on local host
%define with_xen           0%{!?_without_xen:%{server_drivers}}
%define with_qemu          0%{!?_without_qemu:%{server_drivers}}
%define with_openvz        0%{!?_without_openvz:%{server_drivers}}
%define with_lxc           0%{!?_without_lxc:%{server_drivers}}
%define with_vbox          0%{!?_without_vbox:%{server_drivers}}
%define with_uml           0%{!?_without_uml:%{server_drivers}}
%define with_libxl         0%{!?_without_libxl:%{server_drivers}}
%define with_vmware        0%{!?_without_vmware:%{server_drivers}}

# Then the hypervisor drivers that talk via a native remote protocol
%define with_phyp          0%{!?_without_phyp:1}
%define with_esx           0%{!?_without_esx:1}
%define with_hyperv        0%{!?_without_hyperv:1}
%define with_xenapi        0%{!?_without_xenapi:1}

# Then the secondary host drivers
%define with_network       0%{!?_without_network:%{server_drivers}}
%define with_storage_fs    0%{!?_without_storage_fs:%{server_drivers}}
%define with_storage_lvm   0%{!?_without_storage_lvm:%{server_drivers}}
%define with_storage_iscsi 0%{!?_without_storage_iscsi:%{server_drivers}}
%define with_storage_disk  0%{!?_without_storage_disk:%{server_drivers}}
%define with_storage_mpath 0%{!?_without_storage_mpath:%{server_drivers}}
%define with_numactl       0%{!?_without_numactl:%{server_drivers}}
%define with_selinux       0%{!?_without_selinux:%{server_drivers}}

# A few optional bits off by default, we enable later
%define with_polkit        0%{!?_without_polkit:0}
%define with_capng         0%{!?_without_capng:0}
%define with_netcf         0%{!?_without_netcf:0}
%define with_udev          0%{!?_without_udev:0}
%define with_hal           0%{!?_without_hal:0}
%define with_yajl          0%{!?_without_yajl:0}
%define with_nwfilter      0%{!?_without_nwfilter:0}
%define with_libpcap       0%{!?_without_libpcap:0}
%define with_macvtap       0%{!?_without_macvtap:0}
%define with_libnl         0%{!?_without_libnl:0}
%define with_audit         0%{!?_without_audit:0}
%define with_dtrace        0%{!?_without_dtrace:0}
%define with_cgconfig      0%{!?_without_cgconfig:0}
%define with_sanlock       0%{!?_without_sanlock:0}
%define with_systemd       0%{!?_without_systemd:0}
%define with_numad         0%{!?_without_numad:0}

# Non-server/HV driver defaults which are always enabled
%define with_python        0%{!?_without_python:1}
%define with_sasl          0%{!?_without_sasl:1}


# Finally set the OS / architecture specific special cases

# Xen is available only on i386 x86_64 ia64
%ifnarch i386 i586 i686 x86_64 ia64
%define with_xen 0
%define with_libxl 0
%endif

# Numactl is not available on s390[x] and ARM
%ifarch s390 s390x %{arm}
%define with_numactl 0
%endif

# RHEL doesn't ship OpenVZ, VBox, UML, PowerHypervisor,
# VMWare, libxenserver (xenapi), libxenlight (Xen 4.1 and newer),
# or HyperV.
%if 0%{?rhel}
%define with_openvz 0
%define with_vbox 0
%define with_uml 0
%define with_phyp 0
%define with_vmware 0
%define with_xenapi 0
%define with_libxl 0
%define with_hyperv 0
%endif

# Although earlier Fedora has systemd, libvirt still used sysvinit
%if 0%{?fedora} >= 17
%define with_systemd 1
%endif

# RHEL-5 has restricted QEMU to x86_64 only and is too old for LXC
%if 0%{?rhel} == 5
%ifnarch x86_64
%define with_qemu 0
%endif
%define with_lxc 0
%endif

# RHEL-6 has restricted QEMU to x86_64 only, stopped including Xen
# on all archs. Other archs all have LXC available though
%if 0%{?rhel} >= 6
%ifnarch x86_64
%define with_qemu 0
%endif
%define with_xen 0
%endif

# Fedora doesn't have any QEMU on ppc64 - only ppc
%if 0%{?fedora}
%ifarch ppc64
%define with_qemu 0
%endif
%endif

# Fedora doesn't have new enough Xen for libxl until F16
%if 0%{?fedora} && 0%{?fedora} < 16
%define with_libxl 0
%endif

# PolicyKit was introduced in Fedora 8 / RHEL-6 or newer
%if 0%{?fedora} >= 8 || 0%{?rhel} >= 6
%define with_polkit    0%{!?_without_polkit:1}
%endif

# libcapng is used to manage capabilities in Fedora 12 / RHEL-6 or newer
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
%define with_capng     0%{!?_without_capng:1}
%endif

# netcf is used to manage network interfaces in Fedora 12 / RHEL-6 or newer
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
%define with_netcf     0%{!?_without_netcf:%{server_drivers}}
%endif

# udev is used to manage host devices in Fedora 12 / RHEL-6 or newer
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
%define with_udev     0%{!?_without_udev:%{server_drivers}}
%else
%define with_hal       0%{!?_without_hal:%{server_drivers}}
%endif

# Enable yajl library for JSON mode with QEMU
%if 0%{?fedora} >= 13 || 0%{?rhel} >= 6
%define with_yajl     0%{!?_without_yajl:%{server_drivers}}
%endif

# Enable sanlock library for lock management with QEMU
# Sanlock is available only on i686 x86_64 for RHEL
%if 0%{?fedora} >= 16
%define with_sanlock 0%{!?_without_sanlock:%{server_drivers}}
%endif
%if 0%{?rhel} >= 6
%ifarch x86_64
%define with_sanlock 0%{!?_without_sanlock:%{server_drivers}}
%endif
%endif

# Disable some drivers when building without libvirt daemon.
# The logic is the same as in configure.ac
%if ! %{with_libvirtd}
%define with_network 0
%define with_qemu 0
%define with_lxc 0
%define with_uml 0
%define with_hal 0
%define with_udev 0
%define with_storage_fs 0
%define with_storage_lvm 0
%define with_storage_iscsi 0
%define with_storage_mpath 0
%define with_storage_disk 0
%endif

%if %{with_qemu}
%define with_nwfilter 0%{!?_without_nwfilter:%{server_drivers}}
# Enable libpcap library
%define with_libpcap  0%{!?_without_libpcap:%{server_drivers}}
%define with_macvtap  0%{!?_without_macvtap:%{server_drivers}}

# numad is used to manage the CPU placement dynamically,
# it's not available on s390[x] and ARM.
%if 0%{?fedora} >= 17 || 0%{?rhel} >= 6
%ifnarch s390 s390x %{arm}
%define with_numad    0%{!?_without_numad:%{server_drivers}}
%endif
%endif
%endif

%if %{with_macvtap}
%define with_libnl 1
%endif

%if 0%{?fedora} >= 11 || 0%{?rhel} >= 5
%define with_audit    0%{!?_without_audit:1}
%endif

%if 0%{?fedora} >= 13 || 0%{?rhel} >= 6
%define with_dtrace 1
%endif

# Pull in cgroups config system
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
%if %{with_qemu} || %{with_lxc}
%define with_cgconfig 0%{!?_without_cgconfig:1}
%endif
%endif

# Force QEMU to run as non-root
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
%define qemu_user  qemu
%define qemu_group  qemu
%else
%define qemu_user  root
%define qemu_group  root
%endif


# The RHEL-5 Xen package has some feature backports. This
# flag is set to enable use of those special bits on RHEL-5
%if 0%{?rhel} == 5
%define with_rhel5  1
%else
%define with_rhel5  0
%endif

Summary: Library providing a simple virtualization API
Name: libvirt
Version: 0.9.10
Release: 21%{?dist}.5%{?extra_release}
License: LGPLv2+
Group: Development/Libraries
Source: http://libvirt.org/sources/libvirt-%{version}.tar.gz

# RHEL only patches
Patch1: libvirt-Support-virtio-disk-hotplug-in-JSON-mode.patch
Patch2: libvirt-Support-password-expiry-and-connected-in-the-QEMU-driver.patch
Patch3: libvirt-Support-seamless-migration-of-SPICE-graphics-clients.patch
Patch4: libvirt-Emit-graphics-events-when-a-SPICE-client-connects-disconnects.patch
Patch5: libvirt-Switch-to-private-redhat-namespace-for-QMP-I-O-error-reason.patch
Patch6: libvirt-Disable-KSM-on-domain-startup.patch
Patch7: libvirt-screenshot-Implement-multiple-screen-support.patch
Patch8: libvirt-daemon-Modify-init-script-to-detect-upstart-managed-libvirtd.patch
Patch9: libvirt-cpu-Disable-tsc-deadline-feature-not-supported-in-qemu-on-RHEL-6.3.patch
Patch10: libvirt-qemu-fix-virtio-macvtap-migration-from-6.3-to-older-hosts.patch

Patch11: libvirt-blockjob-react-to-active-block-copy.patch
Patch12: libvirt-blockjob-add-qemu-capabilities-related-to-block-jobs.patch
Patch13: libvirt-blockjob-return-appropriate-event-and-info.patch
Patch14: libvirt-blockjob-support-pivot-operation-on-cancel.patch
Patch15: libvirt-blockjob-make-drive-reopen-safer.patch
Patch16: libvirt-blockjob-implement-block-copy-for-qemu.patch
Patch17: libvirt-blockjob-allow-for-existing-files.patch
Patch18: libvirt-blockjob-allow-mirroring-under-SELinux.patch
Patch19: libvirt-blockjob-accommodate-RHEL-backport-names.patch
Patch20: libvirt-blockjob-check-for-active-vm-before-checking-blockcopy-bits.patch
Patch21: libvirt-blockjob-allow-speed-setting-in-block-copy.patch
Patch22: libvirt-blockjob-allow-block-devices-past-cgroup.patch
Patch23: libvirt-Disable-keepalives-by-default.patch

# Upstream patches
Patch100: libvirt-qemu-Set-capabilities-based-on-supported-monitor-commands.patch
Patch101: libvirt-qemu-Implement-DomainPMSuspendForDuration.patch
Patch102: libvirt-snapshot-fix-snapshot-deletion-use-after-free.patch
Patch103: libvirt-storage-Allow-runtime-detection-of-scrub.patch
Patch104: libvirt-qemu-Unlock-monitor-when-connecting-to-dest-qemu-fails.patch
Patch105: libvirt-qemu-Prevent-crash-of-libvirtd-without-guest-agent.patch
Patch106: libvirt-python-Expose-virDomain-G-S-etInterfaceParameters-APIs-in-python-binding.patch
Patch107: libvirt-daemon-plug-memory-leak.patch
Patch108: libvirt-daemon-fix-logic-bug-with-virAsprintf.patch
Patch109: libvirt-util-Fix-virFileAccessibleAs-return-path-from-parent.patch
Patch110: libvirt-Add-support-for-unsafe-migration.patch
Patch111: libvirt-virsh-Add-unsafe-option-to-migrate-command.patch
Patch112: libvirt-Introduce-virStorageFileIsClusterFS.patch
Patch113: libvirt-qemu-Forbid-migration-with-cache-none.patch
Patch114: libvirt-qemu-nicer-error-message-on-failed-graceful-destroy.patch
Patch115: libvirt-Error-out-when-using-SPICE-TLS-with-spice_tls-0.patch
Patch116: libvirt-Fixed-URI-parsing.patch
Patch117: libvirt-virsh-fix-informational-message-in-iface-bridge-command.patch
Patch118: libvirt-Improve-error-reporting-when-virsh-console-is-run-without-a-TTY.patch
Patch119: libvirt-pidfile-Make-checking-binary-path-in-virPidFileRead-optional.patch
Patch120: libvirt-Add-flags-for-virDomainOpenConsole.patch
Patch121: libvirt-virsh-add-support-for-VIR_DOMAIN_CONSOLE_-flags.patch
Patch122: libvirt-fdstream-Emit-stream-abort-callback-even-if-poll-doesnt.patch
Patch123: libvirt-fdstream-Add-internal-callback-on-stream-close.patch
Patch124: libvirt-util-Add-helpers-for-safe-domain-console-operations.patch
Patch125: libvirt-qemu-Add-ability-to-abort-existing-console-while-creating-new-one.patch
Patch126: libvirt-qemu-Don-t-emit-tls-port-spice-option-if-port-is-1.patch
Patch127: libvirt-docs-comments-wiping-supported-algorithms.patch
Patch128: libvirt-libvirt-guests-Add-documentation-and-clean-up-to-use-virsh-s-improved-list.patch
Patch129: libvirt-libvirt-guests-Don-t-try-to-do-a-managed-save-of-transient-guests.patch
Patch130: libvirt-virsh-Enhance-list-command-to-ease-creation-of-shell-scripts.patch
Patch131: libvirt-libvirt-guests-Check-if-URI-is-reachable-before-launching-commands.patch
Patch132: libvirt-hooks-Add-support-for-capturing-hook-output.patch
Patch133: libvirt-qemu-Add-pre-migration-hook.patch
Patch134: libvirt-Support-for-cpu64-rhel-qemu-cpu-models.patch
Patch135: libvirt-util-Add-netlink-event-handling-to-virnetlink.c.patch
Patch136: libvirt-Add-de-association-handling-to-macvlan-code.patch
Patch137: libvirt-qemu-add-ibmvscsi-controller-model.patch
Patch138: libvirt-qemu-add-virtio-scsi-controller-model.patch
Patch139: libvirt-conf-Add-helper-function-to-look-up-disk-controller-model.patch
Patch140: libvirt-conf-Introduce-new-attribute-for-device-address-format.patch
Patch141: libvirt-qemu-New-cap-flag-to-indicate-if-channel-is-supported-by-scsi-disk.patch
Patch142: libvirt-qemu-Build-command-line-for-the-new-address-format.patch
Patch143: libvirt-tests-Add-tests-for-virtio-scsi-and-ibmvscsi-controllers.patch
Patch144: libvirt-virsh-Two-new-helper-functions-for-disk-device-changes.patch
Patch145: libvirt-virsh-Use-vshFindDisk-and-vshPrepareDiskXML-in-cmdDetachDisk.patch
Patch146: libvirt-virsh-New-command-cmdChangeMedia.patch
Patch147: libvirt-qemu-require-json-for-block-jobs.patch
Patch148: libvirt-qemu-pass-block-pull-backing-file-to-monitor.patch
Patch149: libvirt-virsh-expose-partial-pull.patch
Patch150: libvirt-libvirt-guests-Add-parallel-startup-and-shutdown-of-guests.patch
Patch151: libvirt-qemu-Shared-or-readonly-disks-are-always-safe-wrt-migration.patch
Patch152: libvirt-util-eliminate-crash-in-virNetDevMacVLanCreateWithVPortProfile.patch
Patch153: libvirt-rpc-Fix-client-crash-on-connection-close.patch
Patch154: libvirt-conf-add-missing-device-types-to-virDomainDevice-Type-Def.patch
Patch155: libvirt-conf-relocate-virDomainDeviceDef-and-virDomainHostdevDef.patch
Patch156: libvirt-conf-reorder-static-functions-in-domain_conf.c.patch
Patch157: libvirt-qemu-rename-virDomainDeviceInfoPtr-variables-to-avoid-confusion.patch
Patch158: libvirt-conf-add-device-pointer-to-args-of-virDomainDeviceInfoIterate-callback.patch
Patch159: libvirt-conf-make-hostdev-info-a-separate-object.patch
Patch160: libvirt-conf-HostdevDef-parse-format-helper-functions.patch
Patch161: libvirt-conf-give-each-hostdevdef-a-parent-pointer.patch
Patch162: libvirt-conf-put-subsys-part-of-virDomainHostdevDef-into-its-own-struct.patch
Patch163: libvirt-conf-hostdev-utility-functions.patch
Patch164: libvirt-qemu-re-order-functions-in-qemu_hotplug.c.patch
Patch165: libvirt-qemu-refactor-hotplug-detach-of-hostdevs.patch
Patch166: libvirt-conf-parse-format-type-hostdev-network-interfaces.patch
Patch167: libvirt-qemu-support-type-hostdev-network-devices-at-domain-start.patch
Patch168: libvirt-conf-change-virDomainNetRemove-from-static-to-global.patch
Patch169: libvirt-qemu-use-virDomainNetRemove-instead-of-inline-code.patch
Patch170: libvirt-qemu-support-type-hostdev-network-device-live-hotplug-attach-detach.patch
Patch171: libvirt-util-two-new-pci-util-functions.patch
Patch172: libvirt-util-support-functions-for-mac-portprofile-associations-on-hostdev.patch
Patch173: libvirt-util-Changes-to-support-portprofiles-for-hostdevs.patch
Patch174: libvirt-qemu-install-port-profile-and-mac-address-on-netdev-hostdevs.patch
Patch175: libvirt-Fix-build-after-commit-e3ba4025.patch
Patch176: libvirt-avoid-global-variable-shadowed.patch
Patch177: libvirt-add-nodeGetCPUmap-for-getting-available-CPU-IDs-in-a-cpumap.patch
Patch178: libvirt-qemu-driver-for-virDomainGetCPUstats-using-cpuacct-cgroup.patch
Patch179: libvirt-cpu-stats-command-shows-cpu-statistics-information-of-a-domain.patch
Patch180: libvirt-Ensure-max_id-is-initialized-in-linuxParseCPUmap.patch
Patch181: libvirt-rpc-allow-truncated-return-for-virDomainGetCPUStats.patch
Patch182: libvirt-qemu-Don-t-parse-device-twice-in-attach-detach.patch
Patch183: libvirt-sanlock-Fix-condition-left-crippled-while-debugging.patch
Patch184: libvirt-sanlock-Use-STREQ_NULLABLE-instead-of-STREQ-on-strings-that-may-be-null.patch
Patch185: libvirt-qemu-Fix-startupPolicy-for-snapshot-revert.patch
Patch186: libvirt-util-Don-t-overflow-on-errno-in-virFileAccessibleAs.patch
Patch187: libvirt-blockResize-add-flag-for-bytes.patch
Patch188: libvirt-docs-use-correct-terminology-for-1024-bytes.patch
Patch189: libvirt-api-add-overflow-error.patch
Patch190: libvirt-util-new-function-for-scaling-numbers.patch
Patch191: libvirt-xml-share-unit-in-RNG.patch
Patch192: libvirt-xml-output-memory-unit-for-clarity.patch
Patch193: libvirt-storage-support-more-scaling-suffixes.patch
Patch194: libvirt-xml-drop-unenforced-minimum-memory-limit-from-RNG.patch
Patch195: libvirt-xml-use-long-long-internally-to-centralize-overflow-checks.patch
Patch196: libvirt-xml-use-better-types-for-memory-values.patch
Patch197: libvirt-xml-allow-scaled-memory-on-input.patch
Patch198: libvirt-virsh-add-option-aliases.patch
Patch199: libvirt-virsh-use-option-aliases.patch
Patch200: libvirt-virsh-add-command-aliases-and-rename-nodedev-detach.patch
Patch201: libvirt-virsh-improve-storage-unit-parsing.patch
Patch202: libvirt-virsh-improve-memory-unit-parsing.patch
Patch203: libvirt-qemuBuildCommandLine-Don-t-add-tlsPort-if-none-set.patch
Patch204: libvirt-Removed-more-AMD-specific-features-from-cpu64-rhel-models.patch
Patch205: libvirt-qemu-support-disk-filenames-with-comma.patch
Patch206: libvirt-cpustats-collect-VM-user-and-sys-times.patch
Patch207: libvirt-cpustats-report-user-and-sys-times.patch
Patch208: libvirt-qemu-Fix-managed-save-and-snapshots-with-host-mode-CPU.patch
Patch209: libvirt-qemu-make-block-io-tuning-smarter.patch
Patch210: libvirt-cpu-Add-new-flag-supported-by-qemu-to-the-cpu-definition.patch
Patch211: libvirt-Added-support-for-AMD-Bulldozer-CPU.patch
Patch212: libvirt-graphics-Cleanup-port-policy.patch
Patch213: libvirt-qemu-Reverse-condition-in-qemuDomainCheckDiskPresence.patch
Patch214: libvirt-cpu-Add-cpu-definition-for-Intel-Sandy-Bridge-cpu-type.patch
Patch215: libvirt-qemu-Support-numad.patch
Patch216: libvirt-numad-Fix-typo-and-warning.patch
Patch217: libvirt-qemu-Use-scsi-block-for-lun-passthrough-instead-of-scsi-disk.patch
Patch218: libvirt-util-make-virDomainLeaseDefFree-global.patch
Patch219: libvirt-qemu-don-t-remove-hostdev-objects-from-domain-if-operation-fails.patch
Patch220: libvirt-util-eliminate-device-object-leaks-related-to-virDomain-Remove.patch
Patch221: libvirt-virsh-fix-invalid-free.patch
Patch222: libvirt-qemu-eliminate-memory-leak-in-qemuDomainUpdateDeviceConfig.patch
Patch223: libvirt-qemu-support-persistent-hotplug-of-hostdev-devices.patch
Patch224: libvirt-qemu-fix-segfault-when-detaching-non-existent-network-device.patch
Patch225: libvirt-remote-Fix-migration-leaks.patch
Patch226: libvirt-virsh-trim-aliases-from-h-output.patch
Patch227: libvirt-Fix-handling-of-blkio-deviceWeight-empty-string.patch
Patch228: libvirt-snapshot-make-quiesce-a-bit-safer.patch
Patch229: libvirt-python-Avoid-memory-leaks-on-libvirt_virNodeGetMemoryStats.patch
Patch230: libvirt-qemu-Use-unlimited-speed-when-migrating-to-file.patch
Patch231: libvirt-qemu-Add-support-for-domain-cleanup-callbacks.patch
Patch232: libvirt-qemu-Avoid-dangling-migration-in-job-on-shutoff-domains.patch
Patch233: libvirt-qemu-Add-connection-close-callbacks.patch
Patch234: libvirt-qemu-Make-autodestroy-utilize-connection-close-callbacks.patch
Patch235: libvirt-qemu-Avoid-dangling-migration-out-job-when-client-dies.patch
Patch236: libvirt-python-Avoid-memory-leaks-on-libvirt_virNodeGetCPUStats.patch
Patch237: libvirt-util-consolidate-duplicated-error-messages-in-virnetlink.c.patch
Patch238: libvirt-python-add-virDomainGetCPUStats-python-binding-API.patch
Patch239: libvirt-snapshot-add-qemu-capability-for-transaction-command.patch
Patch240: libvirt-snapshot-add-atomic-create-flag.patch
Patch241: libvirt-snapshot-make-offline-qemu-snapshots-atomic.patch
Patch242: libvirt-snapshot-rudimentary-qemu-support-for-atomic-disk-snapshot.patch
Patch243: libvirt-snapshot-add-support-for-qemu-transaction-command.patch
Patch244: libvirt-snapshot-wire-up-qemu-transaction-command.patch
Patch245: libvirt-snapshot-improve-qemu-handling-of-reused-snapshot-targets.patch
Patch246: libvirt-Clarify-virsh-freecell-manpage-entry.patch
Patch247: libvirt-Add-support-for-event-tray-moved-of-removable-disks.patch
Patch248: libvirt-docs-Add-documentation-for-new-attribute-tray-of-disk-target.patch
Patch249: libvirt-conf-Parse-and-for-the-tray-attribute.patch
Patch250: libvirt-qemu-Do-not-start-with-source-for-removable-disks-if-tray-is-open.patch
Patch251: libvirt-qemu-Prohibit-setting-tray-status-as-open-for-block-type-disk.patch
Patch252: libvirt-qemu-Update-tray-status-while-tray-moved-event-is-emitted.patch
Patch253: libvirt-build-fix-incorrect-enum-declaration.patch
Patch254: libvirt-spec-Add-missed-dependancy-for-numad.patch
Patch255: libvirt-qemu-Avoid-entering-monitor-with-locked-driver.patch
Patch256: libvirt-snapshot-don-t-pass-NULL-to-QMP-command-creation.patch
Patch257: libvirt-python-Add-new-helper-functions-for-python-to-C-integral-conversion.patch
Patch258: libvirt-python-make-python-APIs-use-these-helper-functions.patch
Patch259: libvirt-python-improve-conversion-validation.patch
Patch260: libvirt-qemu_agent-Issue-guest-sync-prior-to-every-command.patch
Patch261: libvirt-qemu-fix-memory-leak-in-virDomainGetVcpus.patch
Patch262: libvirt-qemu-reflect-any-memory-rounding-back-to-xml.patch
Patch263: libvirt-conf-allow-fuzz-in-XML-with-cur-balloon-max.patch
Patch264: libvirt-qemu-Start-nested-job-in-qemuDomainCheckEjectableMedia.patch
Patch265: libvirt-virsh-Clarify-escape-sequence.patch
Patch266: libvirt-virsh-plug-memory-leaks-on-failure-path.patch
Patch267: libvirt-conf-Prevent-crash-of-libvirtd-without-channel-target-name.patch
Patch268: libvirt-qemu-Don-t-leak-temporary-list-of-USB-devices.patch
Patch269: libvirt-qemu-Delete-USB-devices-used-by-domain-on-stop.patch
Patch270: libvirt-qemu-Build-activeUsbHostdevs-list-on-process-reconnect.patch
Patch271: libvirt-test-fix-segfault-in-networkxml2argvtest.patch
Patch272: libvirt-conf-Plug-memory-leaks-on-virDomainDiskDefParseXML.patch
Patch273: libvirt-qemu_ga-Don-t-overwrite-errors-on-FSThaw.patch
Patch274: libvirt-Fix-parallel-build-in-docs-directory.patch
Patch275: libvirt-qemu-Make-migration-fail-when-port-profile-association-fails-on-the-dst-host.patch
Patch276: libvirt-Wire-up-loader-to-set-the-QEMU-BIOS-path.patch
Patch277: libvirt-blockjob-add-qemu-capabilities-related-to-block-pull-jobs.patch
Patch278: libvirt-blockjob-add-API-for-async-virDomainBlockJobAbort.patch
Patch279: libvirt-blockjob-optimize-JSON-event-handler-lookup.patch
Patch280: libvirt-blockjob-wire-up-qemu-async-virDomainBlockJobAbort.patch
Patch281: libvirt-blockjob-allow-for-fast-finishing-job.patch
Patch282: libvirt-virsh-minor-syntactic-cleanups.patch
Patch283: libvirt-qemu-use-consistent-error-when-qemu-binary-is-too-old.patch
Patch284: libvirt-blockjob-add-virsh-blockpull-wait.patch
Patch285: libvirt-qemu-Fix-deadlock-when-qemuDomainOpenConsole-cleans-up-a-connection.patch
Patch286: libvirt-qemu-Fix-mem-leak-in-qemuProcessInitCpuAffinity.patch
Patch287: libvirt-numad-Convert-node-list-to-cpumap-before-setting-affinity.patch
Patch288: libvirt-numad-Ignore-cpuset-if-placement-is-auto.patch
Patch289: libvirt-conf-Do-not-parse-cpuset-only-if-the-placement-is-auto.patch
Patch290: libvirt-qemu-util-on-restart-of-libvirt-restart-vepa-callbacks.patch
Patch291: libvirt-qemu-util-fix-netlink-callback-registration-for-migration.patch
Patch292: libvirt-util-only-register-callbacks-for-CREATE-operations-in-virnetdevmacvlan.c.patch
Patch293: libvirt-blockjob-add-new-API-flags.patch
Patch294: libvirt-blockjob-add-blockcopy-to-virsh.patch
Patch295: libvirt-blockjob-enhance-xml-to-track-mirrors-across-libvirtd-restart.patch
# following 9 patches for blockjob are not upstream at commit time
Patch296: libvirt-virsh-avoid-strtol.patch
Patch297: libvirt-conf-tighten-up-XML-integer-parsing.patch
Patch298: libvirt-snapshot-fix-memory-leak-on-error.patch
Patch299: libvirt-virsh-avoid-uninitialized-memory-usage.patch
Patch300: libvirt-qemu-improve-errors-related-to-offline-domains.patch
Patch301: libvirt-qemu-Preserve-original-error-during-migration.patch
Patch302: libvirt-rpc-Discard-non-blocking-calls-only-when-necessary.patch
Patch303: libvirt-qemu-Fix-detection-of-failed-migration.patch
Patch304: libvirt-qemu-Avoid-bogus-error-at-the-end-of-tunnelled-migration.patch
Patch305: libvirt-qemu-Make-sure-qemu-can-access-its-directory-in-hugetlbfs.patch
Patch306: libvirt-virsh-Fix-docs-for-list-command.patch
Patch307: libvirt-virsh-Fix-and-clarify-the-title-flag-for-the-list-command-in-man-page.patch
Patch308: libvirt-qemuOpenFile-Don-t-force-chown-on-NFS.patch
Patch309: libvirt-util-fix-crash-when-starting-macvtap-interfaces.patch
Patch310: libvirt-qemu-Fix-segfault-when-host-CPU-is-empty.patch
Patch311: libvirt-blockjob-fix-block-stream-bandwidth-race.patch
Patch312: libvirt-qemu-don-t-modify-domain-on-failed-blockiotune.patch
Patch313: libvirt-qemu-reject-blockiotune-if-qemu-too-old.patch
Patch314: libvirt-qemu-Don-t-use-virDomainDefFormat-directly.patch
Patch315: libvirt-qemu-Emit-compatible-XML-when-migrating-a-domain.patch
Patch316: libvirt-usb-create-functions-to-search-usb-device-accurately.patch
Patch317: libvirt-qemu-call-usb-search-function-for-hostdev-initialization-and-hotplug.patch
Patch318: libvirt-virsh-avoid-heap-corruption-leading-to-virsh-abort.patch
Patch319: libvirt-util-fix-libvirtd-startup-failure-due-to-netlink-error.patch
Patch320: libvirt-util-allow-specifying-both-src-and-dst-pid-in-virNetlinkCommand.patch
Patch321: libvirt-util-function-to-get-local-nl_pid-used-by-netlink-event-socket.patch
Patch322: libvirt-util-set-src_pid-for-virNetlinkCommand-when-appropriate.patch
Patch323: libvirt-domain_conf-add-usbredir-to-list-of-valid-spice-channels.patch
Patch324: libvirt-domain_conf-add-default-to-list-of-valid-spice-channels.patch
Patch325: libvirt-snapshot-allow-block-devices-past-cgroup.patch
Patch326: libvirt-util-Avoid-libvirtd-crash-in-virNetDevTapCreate.patch
Patch327: libvirt-python-Fix-the-forward_null-error-in-Python-binding-codes.patch
Patch328: libvirt-xen-Fix-resource-leak-in-xen-driver.patch
Patch329: libvirt-test-Fix-resource-leak-in-test-driver.patch
Patch330: libvirt-node-Fix-resource-leak-in-nodeinfo.c.patch
Patch331: libvirt-virnet-Fix-resource-leak-in-virnetlink.c.patch
Patch332: libvirt-vmx-fix-resource-leak.patch
Patch333: libvirt-qemu-fix-resource-leak.patch
Patch334: libvirt-uuid-fix-possible-non-terminated-string.patch
Patch335: libvirt-node_device-fix-possible-non-terminated-string.patch
Patch336: libvirt-numad-Set-memory-policy-from-numad-advisory-nodeset.patch
Patch337: libvirt-numad-Copy-placement-of-numatune-to-vcpu-by-default.patch
Patch338: libvirt-numad-Always-output-placement-of-vcpu.patch
Patch339: libvirt-qemu-Avoid-the-memory-allocation-and-freeing.patch
Patch340: libvirt-numad-Divide-cur_balloon-by-1024-before-passing-it-to-numad.patch
Patch341: libvirt-numad-Check-numactl-devel-if-compiled-with-numad-support.patch
Patch342: libvirt-build-Fix-the-typo-in-configure.ac.patch
Patch343: libvirt-qemu-fix-build-when-HAVE_NUMACTL.patch
Patch344: libvirt-usb-fix-crash-when-failing-to-attach-a-second-usb-device.patch
Patch345: libvirt-qemu-Use-the-CPU-index-in-capabilities-to-map-NUMA-node-to-cpu-list.patch
Patch346: libvirt-qemu-Set-memory-policy-using-cgroup-if-placement-is-auto.patch
Patch347: libvirt-Fix-virDomainDeviceInfoIsSet-to-check-all-struct-fields.patch
Patch348: libvirt-Fix-logic-for-assigning-PCI-addresses-to-USB2-companion-controllers.patch
Patch349: libvirt-Set-a-sensible-default-master-start-port-for-ehci-companion-controllers.patch
Patch350: libvirt-qemu-Rollback-on-used-USB-devices.patch
Patch351: libvirt-qemu-Don-t-delete-USB-device-on-failed-qemuPrepareHostdevUSBDevices.patch
Patch352: libvirt-Revert-rpc-Discard-non-blocking-calls-only-when-necessary.patch
Patch353: libvirt-avoid-closing-uninitialized-fd.patch
Patch354: libvirt-avoid-fd-leak.patch
Patch355: libvirt-command-avoid-double-close-bugs.patch
Patch356: libvirt-fdstream-avoid-double-close-bug.patch
Patch357: libvirt-command-check-for-fork-error-before-closing-fd.patch
Patch358: libvirt-qemu-avoid-closing-fd-more-than-once.patch
Patch359: libvirt-qemu_hotplug-Don-t-free-the-PCI-device-structure-after-hot-unplug.patch
Patch360: libvirt-nodeinfo-drop-static-variable.patch
Patch361: libvirt-nodeinfo-avoid-probing-host-filesystem-during-test.patch
Patch362: libvirt-nodeinfo-add-some-more-tests.patch
Patch363: libvirt-nodeinfo-Get-the-correct-CPU-number-on-AMD-Magny-Cours-platform.patch
Patch364: libvirt-nodeinfo-test-more-details.patch
Patch365: libvirt-sanlock-fix-locking-for-readonly-devices.patch
Patch366: libvirt-Add-support-for-shared-sanlock-leases.patch
Patch367: libvirt-Fix-compilation-on-older-sanlock.patch
Patch368: libvirt-daemon-Fix-crash-in-virTypedParameterArrayClear.patch
Patch369: libvirt-remote-Fix-locking-in-stream-APIs.patch
Patch370: libvirt-Using-virOnce-for-global-initialization-is-desirable.patch
Patch371: libvirt-json-fix-interface-locale-dependency.patch
Patch372: libvirt-security-Fix-libvirtd-crash-possibility.patch
Patch373: libvirt-fix-augeas-test-of-shared-sanlock-leases.patch
Patch374: libvirt-qemu-augeas-Add-spice_tls-spice_tls_x509_cert_dir.patch
Patch375: libvirt-Fix-mistakes-in-augeas-lens.patch
Patch376: libvirt-qemu-Fix-failure-path-in-disk-hotplug.patch
Patch377: libvirt-blockjob-relabel-entire-existing-chain.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
URL: http://libvirt.org/

# All runtime requirements for the libvirt package (runtime requrements
# for subpackages are listed later in those subpackages)

# The client side, i.e. shared libs and virsh are in a subpackage
Requires: %{name}-client = %{version}-%{release}

# Used by many of the drivers, so turn it on whenever the
# daemon is present
%if %{with_libvirtd}
# for modprobe of pci devices
Requires: module-init-tools
# for /sbin/ip & /sbin/tc
Requires: iproute
%if %{with_avahi}
Requires: avahi-libs
%endif
%endif
%if %{with_network}
Requires: dnsmasq >= 2.41
Requires: radvd
%endif
%if %{with_network} || %{with_nwfilter}
Requires: iptables
Requires: iptables-ipv6
%endif
%if %{with_nwfilter}
Requires: ebtables
%endif
# needed for device enumeration
%if %{with_hal}
Requires: hal
%endif
%if %{with_udev}
Requires: udev >= 145
%endif
%if %{with_polkit}
%if 0%{?fedora} >= 12 || 0%{?rhel} >=6
Requires: polkit >= 0.93
%else
Requires: PolicyKit >= 0.6
%endif
%endif
%if %{with_storage_fs}
Requires: nfs-utils
# For mkfs
Requires: util-linux-ng
# For pool-build probing for existing pools
BuildRequires: libblkid-devel >= 2.17
# For glusterfs
%if 0%{?fedora} >= 11
Requires: glusterfs-client >= 2.0.1
%endif
%endif
%if %{with_qemu}
# From QEMU RPMs
Requires: /usr/bin/qemu-img
# For image compression
Requires: gzip
Requires: bzip2
Requires: lzop
Requires: xz
%else
%if %{with_xen}
# From Xen RPMs
Requires: /usr/sbin/qcow-create
%endif
%endif
%if %{with_storage_lvm}
# For LVM drivers
Requires: lvm2
%endif
%if %{with_storage_iscsi}
# For ISCSI driver
Requires: iscsi-initiator-utils
%endif
%if %{with_storage_disk}
# For disk driver
Requires: parted
Requires: device-mapper
%endif
%if %{with_storage_mpath}
# For multipath support
Requires: device-mapper
%endif
%if %{with_cgconfig}
Requires: libcgroup
%endif
%ifarch i386 i586 i686 x86_64 ia64
# For virConnectGetSysinfo
Requires: dmidecode
%endif
# For service management
%if %{with_systemd}
Requires(post): systemd-units
Requires(post): systemd-sysv
Requires(preun): systemd-units
Requires(postun): systemd-units
%endif
%if %{with_numad}
Requires: numad
%endif

# All build-time requirements
%if 0%{?enable_autotools}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: gettext-devel
BuildRequires: libtool
%endif
BuildRequires: python-devel
%if %{with_systemd}
BuildRequires: systemd-units
%endif
%if %{with_xen}
BuildRequires: xen-devel
%endif
BuildRequires: libxml2-devel
BuildRequires: xhtml1-dtds
BuildRequires: libxslt
BuildRequires: readline-devel
BuildRequires: ncurses-devel
BuildRequires: gettext
BuildRequires: libtasn1-devel
BuildRequires: gnutls-devel
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
# for augparse, optionally used in testing
BuildRequires: augeas
%endif
%if %{with_hal}
BuildRequires: hal-devel
%endif
%if %{with_udev}
BuildRequires: libudev-devel >= 145
BuildRequires: libpciaccess-devel >= 0.10.9
%endif
%if %{with_yajl}
BuildRequires: yajl-devel
%endif
%if %{with_sanlock}
BuildRequires: sanlock-devel >= 1.8
%endif
%if %{with_libpcap}
BuildRequires: libpcap-devel
%endif
%if %{with_libnl}
BuildRequires: libnl-devel
%endif
%if %{with_avahi}
BuildRequires: avahi-devel
%endif
%if %{with_selinux}
BuildRequires: libselinux-devel
%endif
%if %{with_network}
BuildRequires: dnsmasq >= 2.41
BuildRequires: iptables
BuildRequires: iptables-ipv6
BuildRequires: radvd
%endif
%if %{with_nwfilter}
BuildRequires: ebtables
%endif
BuildRequires: module-init-tools
%if %{with_sasl}
BuildRequires: cyrus-sasl-devel
%endif
%if %{with_polkit}
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
# Only need the binary, not -devel
BuildRequires: polkit >= 0.93
%else
BuildRequires: PolicyKit-devel >= 0.6
%endif
%endif
%if %{with_storage_fs}
# For mount/umount in FS driver
BuildRequires: util-linux
%endif
%if %{with_qemu}
# From QEMU RPMs
BuildRequires: /usr/bin/qemu-img
%else
%if %{with_xen}
# From Xen RPMs
BuildRequires: /usr/sbin/qcow-create
%endif
%endif
%if %{with_storage_lvm}
# For LVM drivers
BuildRequires: lvm2
%endif
%if %{with_storage_iscsi}
# For ISCSI driver
BuildRequires: iscsi-initiator-utils
%endif
%if %{with_storage_disk}
# For disk driver
BuildRequires: parted-devel
%if 0%{?rhel} == 5
# Broken RHEL-5 parted RPM is missing a dep
BuildRequires: e2fsprogs-devel
%endif
%endif
%if %{with_storage_mpath}
# For Multipath support
%if 0%{?rhel} == 5
# Broken RHEL-5 packaging has header files in main RPM :-(
BuildRequires: device-mapper
%else
BuildRequires: device-mapper-devel
%endif
%endif
%if %{with_numactl}
# For QEMU/LXC numa info
BuildRequires: numactl-devel
%endif
%if %{with_capng}
BuildRequires: libcap-ng-devel >= 0.5.0
%endif
%if %{with_phyp}
BuildRequires: libssh2-devel
%endif
%if %{with_netcf}
%if 0%{?fedora} >= 16 || 0%{?rhel} >= 6
BuildRequires: netcf-devel >= 0.1.8
%else
BuildRequires: netcf-devel >= 0.1.4
%endif
%endif
%if %{with_esx}
%if 0%{?fedora} >= 9 || 0%{?rhel} >= 6
BuildRequires: libcurl-devel
%else
BuildRequires: curl-devel
%endif
%endif
%if %{with_hyperv}
BuildRequires: libwsman-devel >= 2.2.3
%endif
%if %{with_audit}
BuildRequires: audit-libs-devel
%endif
%if %{with_dtrace}
# we need /usr/sbin/dtrace
BuildRequires: systemtap-sdt-devel
%endif

%if %{with_storage_fs}
# For mount/umount in FS driver
BuildRequires: util-linux
# For showmount in FS driver (netfs discovery)
BuildRequires: nfs-utils
%endif

# Fedora build root suckage
BuildRequires: gawk

# For storage wiping with different algorithms
BuildRequires: scrub

%if %{with_numad}
BuildRequires: numad
%endif

%description
Libvirt is a C toolkit to interact with the virtualization capabilities
of recent versions of Linux (and other OSes). The main package includes
the libvirtd server exporting the virtualization support.

%package client
Summary: Client side library and utilities of the libvirt library
Group: Development/Libraries
Requires: readline
Requires: ncurses
# So remote clients can access libvirt over SSH tunnel
# (client invokes 'nc' against the UNIX socket on the server)
Requires: nc
# Needed by libvirt-guests init script.
Requires: gettext
# Needed by virt-pki-validate script.
Requires: gnutls-utils
# Needed for probing the power management features of the host.
Requires: pm-utils
%if %{with_sasl}
Requires: cyrus-sasl
# Not technically required, but makes 'out-of-box' config
# work correctly & doesn't have onerous dependencies
Requires: cyrus-sasl-md5
%endif

%description client
Shared libraries and client binaries needed to access to the
virtualization capabilities of recent versions of Linux (and other OSes).

%package devel
Summary: Libraries, includes, etc. to compile with the libvirt library
Group: Development/Libraries
Requires: %{name}-client = %{version}-%{release}
Requires: pkgconfig
%if %{with_xen}
Requires: xen-devel
%endif

%description devel
Includes and documentations for the C library providing an API to use
the virtualization capabilities of recent versions of Linux (and other OSes).

%if %{with_sanlock}
%package lock-sanlock
Summary: Sanlock lock manager plugin for QEMU driver
Group: Development/Libraries
Requires: sanlock >= 1.8
#for virt-sanlock-cleanup require augeas
Requires: augeas
Requires: %{name} = %{version}-%{release}

%description lock-sanlock
Includes the Sanlock lock manager plugin for the QEMU
driver
%endif

%if %{with_python}
%package python
Summary: Python bindings for the libvirt library
Group: Development/Libraries
Requires: %{name}-client = %{version}-%{release}

%description python
The libvirt-python package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libvirt library to use the virtualization capabilities
of recent versions of Linux (and other OSes).
%endif

%prep
%setup -q

# RHEL-only patches
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1

#upstream patches
%patch100 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1
%patch108 -p1
%patch109 -p1
%patch110 -p1
%patch111 -p1
%patch112 -p1
%patch113 -p1
%patch114 -p1
%patch115 -p1
%patch116 -p1
%patch117 -p1
%patch118 -p1
%patch119 -p1
%patch120 -p1
%patch121 -p1
%patch122 -p1
%patch123 -p1
%patch124 -p1
%patch125 -p1
%patch126 -p1
%patch127 -p1
%patch128 -p1
%patch129 -p1
%patch130 -p1
%patch131 -p1
%patch132 -p1
%patch133 -p1
%patch134 -p1
%patch135 -p1
%patch136 -p1
%patch137 -p1
%patch138 -p1
%patch139 -p1
%patch140 -p1
%patch141 -p1
%patch142 -p1
%patch143 -p1
%patch144 -p1
%patch145 -p1
%patch146 -p1
%patch147 -p1
%patch148 -p1
%patch149 -p1
%patch150 -p1
%patch151 -p1
%patch152 -p1
%patch153 -p1
%patch154 -p1
%patch155 -p1
%patch156 -p1
%patch157 -p1
%patch158 -p1
%patch159 -p1
%patch160 -p1
%patch161 -p1
%patch162 -p1
%patch163 -p1
%patch164 -p1
%patch165 -p1
%patch166 -p1
%patch167 -p1
%patch168 -p1
%patch169 -p1
%patch170 -p1
%patch171 -p1
%patch172 -p1
%patch173 -p1
%patch174 -p1
%patch175 -p1
%patch176 -p1
%patch177 -p1
%patch178 -p1
%patch179 -p1
%patch180 -p1
%patch181 -p1
%patch182 -p1
%patch183 -p1
%patch184 -p1
%patch185 -p1
%patch186 -p1
%patch187 -p1
%patch188 -p1
%patch189 -p1
%patch190 -p1
%patch191 -p1
%patch192 -p1
%patch193 -p1
%patch194 -p1
%patch195 -p1
%patch196 -p1
%patch197 -p1
%patch198 -p1
%patch199 -p1
%patch200 -p1
%patch201 -p1
%patch202 -p1
%patch203 -p1
%patch204 -p1
%patch205 -p1
%patch206 -p1
%patch207 -p1
%patch208 -p1
%patch209 -p1
%patch210 -p1
%patch211 -p1
%patch212 -p1
%patch213 -p1
%patch214 -p1
# one RHEL-only patch disabling tsc-deadline
%patch9 -p1
%patch215 -p1
%patch216 -p1
%patch217 -p1
%patch218 -p1
%patch219 -p1
%patch220 -p1
%patch221 -p1
%patch222 -p1
%patch223 -p1
%patch224 -p1
%patch225 -p1
%patch226 -p1
%patch227 -p1
%patch228 -p1
%patch229 -p1
%patch230 -p1
%patch231 -p1
%patch232 -p1
%patch233 -p1
%patch234 -p1
%patch235 -p1
%patch236 -p1
%patch237 -p1
%patch238 -p1
%patch239 -p1
%patch240 -p1
%patch241 -p1
%patch242 -p1
%patch243 -p1
%patch244 -p1
%patch245 -p1
%patch246 -p1
%patch247 -p1
%patch248 -p1
%patch249 -p1
%patch250 -p1
%patch251 -p1
%patch252 -p1
%patch253 -p1
%patch254 -p1
%patch255 -p1
%patch256 -p1
%patch257 -p1
%patch258 -p1
%patch259 -p1
%patch260 -p1
%patch261 -p1
%patch262 -p1
%patch263 -p1
%patch264 -p1
%patch265 -p1
%patch266 -p1
%patch267 -p1
%patch268 -p1
%patch269 -p1
%patch270 -p1
# One RHEL only patch for virtio+macvtap migration to older hosts
%patch10 -p1
# upstream patches
%patch271 -p1
%patch272 -p1
%patch273 -p1
%patch274 -p1
%patch275 -p1
%patch276 -p1
%patch277 -p1
%patch278 -p1
%patch279 -p1
%patch280 -p1
%patch281 -p1
%patch282 -p1
%patch283 -p1
%patch284 -p1
%patch285 -p1
%patch286 -p1
%patch287 -p1
%patch288 -p1
%patch289 -p1
%patch290 -p1
%patch291 -p1
%patch292 -p1
%patch293 -p1
%patch294 -p1
%patch295 -p1
# 9 following patches for blockjob are not upstream
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
# upstream again
%patch296 -p1
%patch297 -p1
%patch298 -p1
%patch299 -p1
%patch300 -p1
# One RHEL only patch for blockjob
%patch20 -p1
# upstream patches
%patch301 -p1
%patch302 -p1
%patch303 -p1
%patch304 -p1
%patch305 -p1
%patch306 -p1
%patch307 -p1
%patch308 -p1
%patch309 -p1
%patch310 -p1
# One RHEL only patch for blockjob
%patch21 -p1
# upstream patches
%patch311 -p1
%patch312 -p1
%patch313 -p1
%patch314 -p1
%patch315 -p1
%patch316 -p1
%patch317 -p1
%patch318 -p1
%patch319 -p1
%patch320 -p1
%patch321 -p1
%patch322 -p1
%patch323 -p1
%patch324 -p1
%patch325 -p1
# One RHEL only patch for live snapshot
%patch22 -p1
# upstream patches
%patch326 -p1
%patch327 -p1
%patch328 -p1
%patch329 -p1
%patch330 -p1
%patch331 -p1
%patch332 -p1
%patch333 -p1
%patch334 -p1
%patch335 -p1
%patch336 -p1
%patch337 -p1
%patch338 -p1
%patch339 -p1
%patch340 -p1
%patch341 -p1
%patch342 -p1
%patch343 -p1
%patch344 -p1
%patch345 -p1
%patch346 -p1
%patch347 -p1
%patch348 -p1
%patch349 -p1
%patch350 -p1
%patch351 -p1
%patch352 -p1
# 6.3.z starts here
%patch353 -p1
%patch354 -p1
%patch355 -p1
%patch356 -p1
%patch357 -p1
%patch358 -p1
# RHEL-only
%patch23 -p1
# upstream patches
%patch359 -p1
%patch360 -p1
%patch361 -p1
%patch362 -p1
%patch363 -p1
%patch364 -p1
%patch365 -p1
%patch366 -p1
%patch367 -p1
%patch368 -p1
%patch369 -p1
%patch370 -p1
%patch371 -p1
%patch372 -p1
%patch373 -p1
%patch374 -p1
%patch375 -p1
%patch376 -p1
%patch377 -p1


%build
%if ! %{with_xen}
%define _without_xen --without-xen
%endif

%if ! %{with_qemu}
%define _without_qemu --without-qemu
%endif

%if ! %{with_openvz}
%define _without_openvz --without-openvz
%endif

%if ! %{with_lxc}
%define _without_lxc --without-lxc
%endif

%if ! %{with_vbox}
%define _without_vbox --without-vbox
%endif

%if ! %{with_xenapi}
%define _without_xenapi --without-xenapi
%endif

%if ! %{with_libxl}
%define _without_libxl --without-libxl
%endif

%if ! %{with_sasl}
%define _without_sasl --without-sasl
%endif

%if ! %{with_avahi}
%define _without_avahi --without-avahi
%endif

%if ! %{with_phyp}
%define _without_phyp --without-phyp
%endif

%if ! %{with_esx}
%define _without_esx --without-esx
%endif

%if ! %{with_hyperv}
%define _without_hyperv --without-hyperv
%endif

%if ! %{with_vmware}
%define _without_vmware --without-vmware
%endif

%if ! %{with_polkit}
%define _without_polkit --without-polkit
%endif

%if ! %{with_python}
%define _without_python --without-python
%endif

%if ! %{with_libvirtd}
%define _without_libvirtd --without-libvirtd
%endif

%if ! %{with_uml}
%define _without_uml --without-uml
%endif

%if %{with_rhel5}
%define _with_rhel5_api --with-rhel5-api
%endif

%if ! %{with_network}
%define _without_network --without-network
%endif

%if ! %{with_storage_fs}
%define _without_storage_fs --without-storage-fs
%endif

%if ! %{with_storage_lvm}
%define _without_storage_lvm --without-storage-lvm
%endif

%if ! %{with_storage_iscsi}
%define _without_storage_iscsi --without-storage-iscsi
%endif

%if ! %{with_storage_disk}
%define _without_storage_disk --without-storage-disk
%endif

%if ! %{with_storage_mpath}
%define _without_storage_mpath --without-storage-mpath
%endif

%if ! %{with_numactl}
%define _without_numactl --without-numactl
%endif

%if ! %{with_numad}
%define _without_numad --without-numad
%endif

%if ! %{with_capng}
%define _without_capng --without-capng
%endif

%if ! %{with_netcf}
%define _without_netcf --without-netcf
%endif

%if ! %{with_selinux}
%define _without_selinux --without-selinux
%endif

%if ! %{with_hal}
%define _without_hal --without-hal
%endif

%if ! %{with_udev}
%define _without_udev --without-udev
%endif

%if ! %{with_yajl}
%define _without_yajl --without-yajl
%endif

%if ! %{with_sanlock}
%define _without_sanlock --without-sanlock
%endif

%if ! %{with_libpcap}
%define _without_libpcap --without-libpcap
%endif

%if ! %{with_macvtap}
%define _without_macvtap --without-macvtap
%endif

%if ! %{with_audit}
%define _without_audit --without-audit
%endif

%if ! %{with_dtrace}
%define _without_dtrace --without-dtrace
%endif

%define when  %(date +"%%F-%%T")
%define where %(hostname)
%define who   %{?packager}%{!?packager:Unknown}
%define with_packager --with-packager="%{who}, %{when}, %{where}"
%define with_packager_version --with-packager-version="%{release}"

%if %{with_systemd}
# We use 'systemd+redhat', so if someone installs upstart or
# legacy init scripts, they can still start libvirtd, etc
%define init_scripts --with-init_script=systemd+redhat
%else
%define init_scripts --with-init_script=redhat
%endif

%if 0%{?enable_autotools}
autoreconf -if
%endif
%configure %{?_without_xen} \
           %{?_without_qemu} \
           %{?_without_openvz} \
           %{?_without_lxc} \
           %{?_without_vbox} \
           %{?_without_xenapi} \
           %{?_without_sasl} \
           %{?_without_avahi} \
           %{?_without_polkit} \
           %{?_without_python} \
           %{?_without_libvirtd} \
           %{?_without_uml} \
           %{?_without_phyp} \
           %{?_without_esx} \
           %{?_without_hyperv} \
           %{?_without_vmware} \
           %{?_without_network} \
           %{?_with_rhel5_api} \
           %{?_without_storage_fs} \
           %{?_without_storage_lvm} \
           %{?_without_storage_iscsi} \
           %{?_without_storage_disk} \
           %{?_without_storage_mpath} \
           %{?_without_numactl} \
           %{?_without_numad} \
           %{?_without_capng} \
           %{?_without_netcf} \
           %{?_without_selinux} \
           %{?_without_hal} \
           %{?_without_udev} \
           %{?_without_yajl} \
           %{?_without_sanlock} \
           %{?_without_libpcap} \
           %{?_without_macvtap} \
           %{?_without_audit} \
           %{?_without_dtrace} \
           %{with_packager} \
           %{with_packager_version} \
           --with-qemu-user=%{qemu_user} \
           --with-qemu-group=%{qemu_group} \
           %{init_scripts} \
           --with-remote-pid-file=%{_localstatedir}/run/libvirtd.pid
make %{?_smp_mflags}
gzip -9 ChangeLog

%install
rm -fr %{buildroot}

%makeinstall SYSTEMD_UNIT_DIR=%{buildroot}%{_unitdir}
for i in domain-events/events-c dominfo domsuspend hellolibvirt openauth python xml/nwfilter systemtap
do
  (cd examples/$i ; make clean ; rm -rf .deps .libs Makefile Makefile.in)
done
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/python*/site-packages/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/python*/site-packages/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.a

%if %{with_network}
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/lib/libvirt/dnsmasq/
# We don't want to install /etc/libvirt/qemu/networks in the main %files list
# because if the admin wants to delete the default network completely, we don't
# want to end up re-incarnating it on every RPM upgrade.
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/
cp $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml \
   $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
# Strip auto-generated UUID - we need it generated per-install
sed -i -e "/<uuid>/d" $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
%else
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
%endif
%if ! %{with_qemu}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_qemu.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%endif
%find_lang %{name}

%if ! %{with_lxc}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_lxc.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%endif

%if ! %{with_python}
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/libvirt-python-%{version}
%endif

%if %{client_only}
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/libvirt-%{version}
%endif

%if ! %{with_libvirtd}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter
mv $RPM_BUILD_ROOT%{_datadir}/doc/libvirt-%{version}/html \
   $RPM_BUILD_ROOT%{_datadir}/doc/libvirt-devel-%{version}/
%endif

%if ! %{with_qemu}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.qemu
%endif
%if ! %{with_lxc}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/lxc.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if ! %{with_uml}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.uml
%endif

%clean
rm -fr %{buildroot}

%check
cd tests
# The following test doesn't currently work in a mock build root
for i in daemon-conf
do
  rm -f $i
  printf "#!/bin/sh\nexit 0\n" > $i
  chmod +x $i
done
for i in nodeinfotest.c
do
  printf '#include "testutils.h"\nint main(void){return EXIT_AM_SKIP;}\n' >$i
done
make check

%pre
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
# Normally 'setup' adds this in /etc/passwd, but this is
# here for case of upgrades from earlier Fedora/RHEL. This
# UID/GID pair is reserved for qemu:qemu
getent group kvm >/dev/null || groupadd -g 36 -r kvm
getent group qemu >/dev/null || groupadd -g 107 -r qemu
getent passwd qemu >/dev/null || \
  useradd -r -u 107 -g qemu -G kvm -d / -s /sbin/nologin \
    -c "qemu user" qemu
%endif

%post

%if %{with_libvirtd}
%if %{with_network}
# We want to install the default network for initial RPM installs
# or on the first upgrade from a non-network aware libvirt only.
# We check this by looking to see if the daemon is already installed
if ! /sbin/chkconfig libvirtd && test ! -f %{_sysconfdir}/libvirt/qemu/networks/default.xml
then
    UUID=`/usr/bin/uuidgen`
    sed -e "s,</name>,</name>\n  <uuid>$UUID</uuid>," \
         < %{_datadir}/libvirt/networks/default.xml \
         > %{_sysconfdir}/libvirt/qemu/networks/default.xml
    ln -s ../default.xml %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
fi

# All newly defined networks will have a mac address for the bridge
# auto-generated, but networks already existing at the time of upgrade
# will not. We need to go through all the network configs, look for
# those that don't have a mac address, and add one.

network_files=$( (cd %{_localstatedir}/lib/libvirt/network && \
                  grep -L "mac address" *.xml; \
                  cd %{_sysconfdir}/libvirt/qemu/networks && \
                  grep -L "mac address" *.xml) 2>/dev/null \
                | sort -u)

for file in $network_files
do
   # each file exists in either the config or state directory (or both) and
   # does not have a mac address specified in either. We add the same mac
   # address to both files (or just one, if the other isn't there)

   mac4=`printf '%X' $(($RANDOM % 256))`
   mac5=`printf '%X' $(($RANDOM % 256))`
   mac6=`printf '%X' $(($RANDOM % 256))`
   for dir in %{_localstatedir}/lib/libvirt/network \
              %{_sysconfdir}/libvirt/qemu/networks
   do
      if test -f $dir/$file
      then
         sed -i.orig -e \
           "s|\(<bridge.*$\)|\0\n  <mac address='52:54:00:$mac4:$mac5:$mac6'/>|" \
           $dir/$file
         if test $? != 0
         then
             echo "failed to add <mac address='52:54:00:$mac4:$mac5:$mac6'/>" \
                  "to $dir/$file"
             mv -f $dir/$file.orig $dir/$file
         else
             rm -f $dir/$file.orig
         fi
      fi
   done
done
%endif

%if %{with_systemd}
if [ $1 -eq 1 ] ; then
    # Initial installation
    /bin/systemctl enable libvirtd.service >/dev/null 2>&1 || :
    /bin/systemctl enable cgconfig.service >/dev/null 2>&1 || :
fi
%else
%if %{with_cgconfig}
# Starting with Fedora 16, systemd automounts all cgroups, and cgconfig is
# no longer a necessary service.
%if 0%{?rhel} || (0%{?fedora} && 0%{?fedora} < 16)
if [ "$1" -eq "1" ]; then
/sbin/chkconfig cgconfig on
fi
%endif
%endif

/sbin/chkconfig --add libvirtd
if [ "$1" -ge "1" ]; then
	/sbin/service libvirtd condrestart > /dev/null 2>&1
fi
%endif
%endif

%preun
%if %{with_libvirtd}
%if %{with_systemd}
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    /bin/systemctl --no-reload disable libvirtd.service > /dev/null 2>&1 || :
    /bin/systemctl stop libvirtd.service > /dev/null 2>&1 || :
fi
%else
if [ $1 = 0 ]; then
    /sbin/service libvirtd stop 1>/dev/null 2>&1
    /sbin/chkconfig --del libvirtd
fi
%endif
%endif

%postun
%if %{with_libvirtd}
%if %{with_systemd}
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    # Package upgrade, not uninstall
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
%endif
%endif

%if %{with_libvirtd}
%if %{with_systemd}
%triggerun -- libvirt < 0.9.4
%{_bindir}/systemd-sysv-convert --save libvirtd >/dev/null 2>&1 ||:

# If the package is allowed to autostart:
/bin/systemctl --no-reload enable libvirtd.service >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del libvirtd >/dev/null 2>&1 || :
/bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
%endif
%endif

%preun client

%if %{with_systemd}
%else
if [ $1 = 0 ]; then
    /sbin/chkconfig --del libvirt-guests
    rm -f /var/lib/libvirt/libvirt-guests
fi
%endif

%post client

/sbin/ldconfig
%if %{with_systemd}
%else
/sbin/chkconfig --add libvirt-guests
%endif

%postun client -p /sbin/ldconfig

%if %{with_systemd}
%triggerun client -- libvirt < 0.9.4
%{_bindir}/systemd-sysv-convert --save libvirt-guests >/dev/null 2>&1 ||:

# If the package is allowed to autostart:
/bin/systemctl --no-reload enable libvirt-guests.service >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del libvirt-guests >/dev/null 2>&1 || :
/bin/systemctl try-restart libvirt-guests.service >/dev/null 2>&1 || :
%endif

%if %{with_libvirtd}
%files
%defattr(-, root, root)

%doc AUTHORS ChangeLog.gz NEWS README COPYING.LIB TODO
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/

%if %{with_network}
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/autostart
%endif

%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%{_sysconfdir}/libvirt/nwfilter/*.xml

%{_sysconfdir}/rc.d/init.d/libvirtd
%if %{with_systemd}
%{_unitdir}/libvirtd.service
%endif
%doc daemon/libvirtd.upstart
%config(noreplace) %{_sysconfdir}/sysconfig/libvirtd
%config(noreplace) %{_sysconfdir}/libvirt/libvirtd.conf
%if 0%{?fedora} >= 14 || 0%{?rhel} >= 6
%config(noreplace) %{_sysconfdir}/sysctl.d/libvirtd
%else
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/sysctl.d/libvirtd
%endif
%if %{with_dtrace}
%{_datadir}/systemtap/tapset/libvirt_probes.stp
%{_datadir}/systemtap/tapset/libvirt_functions.stp
%endif
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/uml/
%if %{with_libxl}
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/libxl/
%endif

%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd
%if %{with_qemu}
%config(noreplace) %{_sysconfdir}/libvirt/qemu.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.qemu
%endif
%if %{with_lxc}
%config(noreplace) %{_sysconfdir}/libvirt/lxc.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if %{with_uml}
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.uml
%endif

%dir %{_datadir}/libvirt/

%if %{with_network}
%dir %{_datadir}/libvirt/networks/
%{_datadir}/libvirt/networks/default.xml
%endif

%dir %{_localstatedir}/run/libvirt/

%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/images/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/filesystems/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/boot/
%dir %attr(0711, root, root) %{_localstatedir}/cache/libvirt/

%if %{with_qemu}
%dir %attr(0700, root, root) %{_localstatedir}/run/libvirt/qemu/
%dir %attr(0750, %{qemu_user}, %{qemu_group}) %{_localstatedir}/lib/libvirt/qemu/
%dir %attr(0750, %{qemu_user}, %{qemu_group}) %{_localstatedir}/cache/libvirt/qemu/
%endif
%if %{with_lxc}
%dir %{_localstatedir}/run/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/lxc/
%endif
%if %{with_uml}
%dir %{_localstatedir}/run/libvirt/uml/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/uml/
%endif
%if %{with_libxl}
%dir %{_localstatedir}/run/libvirt/libxl/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/libxl/
%endif
%if %{with_network}
%dir %{_localstatedir}/run/libvirt/network/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/network/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/dnsmasq/
%endif

%if %{with_qemu}
%{_datadir}/augeas/lenses/libvirtd_qemu.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%endif

%if %{with_lxc}
%{_datadir}/augeas/lenses/libvirtd_lxc.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%endif

%{_datadir}/augeas/lenses/libvirtd.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd.aug

%if %{with_polkit}
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%else
%{_datadir}/PolicyKit/policy/org.libvirt.unix.policy
%endif
%endif

%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/

%if %{with_lxc}
%attr(0755, root, root) %{_libexecdir}/libvirt_lxc
%endif

%if %{with_storage_disk}
%attr(0755, root, root) %{_libexecdir}/libvirt_parthelper
%endif

%attr(0755, root, root) %{_libexecdir}/libvirt_iohelper
%attr(0755, root, root) %{_sbindir}/libvirtd

%{_mandir}/man8/libvirtd.8*

%doc docs/*.xml
%endif

%if %{with_sanlock}
%files lock-sanlock
%defattr(-, root, root)
%if %{with_qemu}
%config(noreplace) %{_sysconfdir}/libvirt/qemu-sanlock.conf
%endif
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/sanlock.so
%{_datadir}/augeas/lenses/libvirt_sanlock.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/sanlock
%{_sbindir}/virt-sanlock-cleanup
%{_mandir}/man8/virt-sanlock-cleanup.8*
%endif

%files client -f %{name}.lang
%defattr(-, root, root)
%doc AUTHORS ChangeLog.gz NEWS README COPYING.LIB TODO

%config(noreplace) %{_sysconfdir}/libvirt/libvirt.conf
%{_mandir}/man1/virsh.1*
%{_mandir}/man1/virt-xml-validate.1*
%{_mandir}/man1/virt-pki-validate.1*
%{_mandir}/man1/virt-host-validate.1*
%{_bindir}/virsh
%{_bindir}/virt-xml-validate
%{_bindir}/virt-pki-validate
%{_bindir}/virt-host-validate
%{_libdir}/lib*.so.*

%dir %{_datadir}/libvirt/
%dir %{_datadir}/libvirt/schemas/

%{_datadir}/libvirt/schemas/basictypes.rng
%{_datadir}/libvirt/schemas/capability.rng
%{_datadir}/libvirt/schemas/domain.rng
%{_datadir}/libvirt/schemas/domaincommon.rng
%{_datadir}/libvirt/schemas/domainsnapshot.rng
%{_datadir}/libvirt/schemas/interface.rng
%{_datadir}/libvirt/schemas/network.rng
%{_datadir}/libvirt/schemas/networkcommon.rng
%{_datadir}/libvirt/schemas/nodedev.rng
%{_datadir}/libvirt/schemas/nwfilter.rng
%{_datadir}/libvirt/schemas/secret.rng
%{_datadir}/libvirt/schemas/storageencryption.rng
%{_datadir}/libvirt/schemas/storagepool.rng
%{_datadir}/libvirt/schemas/storagevol.rng

%{_datadir}/libvirt/cpu_map.xml

%{_sysconfdir}/rc.d/init.d/libvirt-guests
%if %{with_systemd}
%{_unitdir}/libvirt-guests.service
%endif
%config(noreplace) %{_sysconfdir}/sysconfig/libvirt-guests
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/

%if %{with_sasl}
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%endif

%files devel
%defattr(-, root, root)

%{_libdir}/lib*.so
%dir %{_includedir}/libvirt
%{_includedir}/libvirt/*.h
%{_libdir}/pkgconfig/libvirt.pc
%dir %{_datadir}/gtk-doc/html/libvirt/
%doc %{_datadir}/gtk-doc/html/libvirt/*.devhelp
%doc %{_datadir}/gtk-doc/html/libvirt/*.html
%doc %{_datadir}/gtk-doc/html/libvirt/*.png
%doc %{_datadir}/gtk-doc/html/libvirt/*.css

%doc docs/*.html docs/html docs/*.gif
%doc docs/libvirt-api.xml
%doc examples/hellolibvirt
%doc examples/domain-events/events-c
%doc examples/dominfo
%doc examples/domsuspend
%doc examples/openauth
%doc examples/xml
%doc examples/systemtap

%if %{with_python}
%files python
%defattr(-, root, root)

%doc AUTHORS NEWS README COPYING.LIB
%{_libdir}/python*/site-packages/libvirt.py*
%{_libdir}/python*/site-packages/libvirt_qemu.py*
%{_libdir}/python*/site-packages/libvirtmod*
%doc python/tests/*.py
%doc python/TODO
%doc examples/python
%doc examples/domain-events/events-python
%endif

%changelog
* Wed Sep 26 2012 Jiri Denemark <jdenemar@redhat.com> - libvirt-0.9.10-21.el6_3.5
- security: Fix libvirtd crash possibility (CVE-2012-4423)
- Fix augeas test of shared sanlock leases (rhbz#858988)
- qemu augeas: Add spice_tls/spice_tls_x509_cert_dir (rhbz#858988)
- Fix mistakes in augeas lens (rhbz#858988)
- qemu: Fix failure path in disk hotplug (rhbz#859376)
- blockjob: Relabel entire existing chain (rhbz#860720)

* Wed Aug 15 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-21.el6_3.4
- daemon: Fix crash in virTypedParameterArrayClear (rhbz#844735)
- remote: Fix locking in stream APIs (rhbz#847946)
- Using virOnce for global initialization is desirable (rhbz#847959)
- json: Fix interface locale dependency (rhbz#847959)

* Wed Jul 11 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-21.el6_3.3
- sanlock: Fix locking for readonly devices (rhbz#838819)
- Add support for shared sanlock leases (rhbz#838819)
- Fix compilation on older sanlock (rhbz#838819)

* Wed Jul  4 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-21.el6_3.2
- qemu_hotplug: Don't free the PCI device structure after hot-unplug (rhbz#836916)
- nodeinfo: Drop static variable (rhbz#836919)
- nodeinfo: Avoid probing host filesystem during test (rhbz#836919)
- nodeinfo: Add some more tests (rhbz#836919)
- nodeinfo: Get the correct CPU number on AMD Magny Cours platform (rhbz#836919)
- nodeinfo: Test more details (rhbz#836919)
- drop sanlock on i686 since it is not available anymore

* Thu Jun 14 2012 Eric Blake <eblake@redhat.com> - libvirt-0.9.10-21.el6_3.1
- avoid closing uninitialized fd (rhbz#827050)
- avoid fd leak (rhbz#827050)
- command: avoid double close bugs (rhbz#827050)
- fdstream: avoid double close bug (rhbz#827050)
- command: check for fork error before closing fd (rhbz#827050)
- qemu: avoid closing fd more than once (rhbz#827050)
- Disable keepalives by default (rhbz#832184)

* Wed May 23 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-21.el6
- qemu: Rollback on used USB devices (rhbz#743671)
- qemu: Don't delete USB device on failed qemuPrepareHostdevUSBDevices (rhbz#743671)
- Revert "rpc: Discard non-blocking calls only when necessary" (rhbz#821468)

* Wed May 16 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-20.el6
- Fix virDomainDeviceInfoIsSet() to check all struct fields (rhbz#820869)
- Fix logic for assigning PCI addresses to USB2 companion controllers (rhbz#820869)
- Set a sensible default master start port for ehci companion controllers (rhbz#820869)

* Tue May 15 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-19.el6
- build: Fix the typo in configure.ac (rhbz#820461)
- qemu: Fix build when !HAVE_NUMACTL (rhbz#820461)
- usb: Fix crash when failing to attach a second usb device (rhbz#815755)
- qemu: Use the CPU index in capabilities to map NUMA node to cpu list. (rhbz#820461)
- qemu: Set memory policy using cgroup if placement is auto (rhbz#820461)

* Wed May  9 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-18.el6
- numad: Set memory policy from numad advisory nodeset (rhbz#810157)
- numad: Copy 'placement' of <numatune> to <vcpu> by default (rhbz#810157)
- numad: Always output 'placement' of <vcpu> (rhbz#810157)
- qemu: Avoid the memory allocation and freeing (rhbz#810157)
- numad: Divide cur_balloon by 1024 before passing it to numad (rhbz#810157)
- numad: Check numactl-devel if compiled with numad support (rhbz#810157)

* Wed May  9 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-17.el6
- qemu: Don't modify domain on failed blockiotune (rhbz#819014)
- qemu: Reject blockiotune if qemu too old (rhbz#819014)
- qemu: Don't use virDomainDefFormat* directly (rhbz#815503)
- qemu: Emit compatible XML when migrating a domain (rhbz#815503)
- usb: Create functions to search usb device accurately (rhbz#815755)
- qemu: Call usb search function for hostdev initialization and hotplug (rhbz#815755)
- virsh: Avoid heap corruption leading to virsh abort (rhbz#819636)
- util: Fix libvirtd startup failure due to netlink error (rhbz#816465)
- util: Allow specifying both src and dst pid in virNetlinkCommand (rhbz#816465)
- util: Function to get local nl_pid used by netlink event socket (rhbz#816465)
- util: Set src_pid for virNetlinkCommand when appropriate (rhbz#816465)
- domain_conf: Add "usbredir" to list of valid spice channels (rhbz#819498)
- domain_conf: Add "default" to list of valid spice channels (rhbz#819499)
- snapshot: Allow block devices past cgroup (rhbz#810200)
- blockjob: Allow block devices past cgroup (rhbz#810200)
- util: Avoid libvirtd crash in virNetDevTapCreate (rhbz#817234)
- python: Fix the forward_null error in Python binding codes (rhbz#771021)
- xen: Fix resource leak in xen driver (rhbz#771021)
- test: Fix resource leak in test driver (rhbz#771021)
- node: Fix resource leak in nodeinfo.c (rhbz#771021)
- virnet: Fix resource leak in virnetlink.c (rhbz#771021)
- vmx: Fix resource leak (rhbz#771021)
- qemu: Fix resource leak (rhbz#771021)
- uuid: Fix possible non-terminated string (rhbz#771021)
- node_device: Fix possible non-terminated string (rhbz#771021)

* Wed May  2 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-16.el6
- qemuOpenFile: Don't force chown on NFS (rhbz#810241)
- util: Fix crash when starting macvtap interfaces (rhbz#815270)
- qemu: Fix segfault when host CPU is empty (rhbz#817078)
- blockjob: Allow speed setting in block copy (rhbz#815791)
- blockjob: Fix block-stream bandwidth race (rhbz#815791)

* Tue May  1 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-15.el6
- qemu: Improve errors related to offline domains (rhbz#816662)
- blockjob: Check for active vm before checking blockcopy bits (rhbz#816662)
- qemu: Preserve original error during migration (rhbz#807907)
- rpc: Discard non-blocking calls only when necessary (rhbz#807907)
- qemu: Fix detection of failed migration (rhbz#807907)
- qemu: Avoid bogus error at the end of tunnelled migration (rhbz#807907)
- qemu: Make sure qemu can access its directory in hugetlbfs (rhbz#815206)
- virsh: Fix docs for list command (rhbz#814021)
- virsh: Fix and clarify the --title flag for the list command in man page (rhbz#814021)

* Tue Apr 24 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-14.el6
- blockjob: Add new API flags (rhbz#638506)
- blockjob: Add 'blockcopy' to virsh (rhbz#638506)
- blockjob: Enhance xml to track mirrors across libvirtd restart (rhbz#638506)
- blockjob: React to active block copy (rhbz#638506)
- blockjob: Add qemu capabilities related to block jobs (rhbz#638506)
- blockjob: Return appropriate event and info (rhbz#638506)
- blockjob: Support pivot operation on cancel (rhbz#638506)
- blockjob: Make drive-reopen safer (rhbz#638506)
- blockjob: Implement block copy for qemu (rhbz#638506)
- blockjob: Allow for existing files (rhbz#638506)
- blockjob: Allow mirroring under SELinux (rhbz#638506)
- blockjob: Accommodate RHEL backport names (rhbz#638506)
- virsh: Avoid strtol (rhbz#813972)
- conf: Tighten up XML integer parsing (rhbz#813972)
- snapshot: Fix memory leak on error (rhbz#782457)
- virsh: Avoid uninitialized memory usage (rhbz#814080)

* Thu Apr 19 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-13.el6
- Fix a problem in the patchset, rhbz#811497 one was applied twice in -12
- qemu, util: On restart of libvirt restart vepa callbacks (rhbz#812430)
- qemu, util: Fix netlink callback registration for migration (rhbz#812430)
- util: Only register callbacks for CREATE operations in virnetdevmacvlan.c (rhbz#812430)

* Wed Apr 18 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-12.el6
- blockjob: Add qemu capabilities related to block pull jobs (rhbz#811683)
- blockjob: Add API for async virDomainBlockJobAbort (rhbz#811683)
- blockjob: Optimize JSON event handler lookup (rhbz#811683)
- blockjob: Wire up qemu async virDomainBlockJobAbort (rhbz#811683)
- blockjob: Allow for fast-finishing job (rhbz#811683)
- virsh: Minor syntactic cleanups (rhbz#811683)
- qemu: Use consistent error when qemu binary is too old (rhbz#811683)
- blockjob: Add virsh blockpull --wait (rhbz#811683)
- qemu: Fix deadlock when qemuDomainOpenConsole cleans up a connection (rhbz#811497)
- qemu: Fix deadlock when qemuDomainOpenConsole cleans up a connection (rhbz#811497)
- qemu: Fix mem leak in qemuProcessInitCpuAffinity (rhbz#810157)
- numad: Convert node list to cpumap before setting affinity (rhbz#810157)
- numad: Ignore cpuset if placement is auto (rhbz#810157)
- conf: Do not parse cpuset only if the placement is auto (rhbz#810157)

* Wed Apr 11 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-11.el6
- test: Fix segfault in networkxml2argvtest (rhbz#810100)
- conf: Plug memory leaks on virDomainDiskDefParseXML (rhbz#575160)
- qemu_ga: Don't overwrite errors on FSThaw (rhbz#808527)
- Fix parallel build in docs/ directory (rhbz#810559)
- qemu: Make migration fail when port profile association fails on the dst host (rhbz#811026)
- Wire up <loader> to set the QEMU BIOS path (rhbz#811227)

* Thu Apr  5 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-10.el6
- python: Add new helper functions for python to C conversion (rhbz#807751)
- python: Make python APIs use these helper functions (rhbz#807751)
- python: Improve conversion validation (rhbz#807751)
- qemu_agent: Issue guest-sync prior to every command (rhbz#808527)
- qemu: Fix memory leak in virDomainGetVcpus (rhbz#808979)
- qemu: Reflect any memory rounding back to xml (rhbz#808522)
- conf: Allow fuzz in XML with cur balloon > max (rhbz#808522)
- qemu: Start nested job in qemuDomainCheckEjectableMedia (rhbz#803186)
- virsh: Clarify escape sequence (rhbz#808652)
- virsh: Plug memory leaks on failure path (rhbz#807555)
- conf: Prevent crash of libvirtd without channel target name (rhbz#808371)
- qemu: Don't leak temporary list of USB devices (rhbz#808459)
- qemu: Delete USB devices used by domain on stop (rhbz#808459)
- qemu: Build activeUsbHostdevs list on process reconnect (rhbz#808459)
- qemu: Fix virtio+macvtap migration from 6.3 to older hosts (rhbz#806633)

* Thu Mar 29 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-9.el6
- qemu: Avoid entering monitor with locked driver (rhbz#803186)
- snapshot: Don't pass NULL to QMP command creation (rhbz#807147)

* Mon Mar 26 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-8.el6
- rebuild, forgot to apply part of the patch
- spec: Add missed dependancy for numad (rhbz#769930)

* Mon Mar 26 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-7.el6
- snapshot: Make quiesce a bit safer (rhbz#804210)
- python: Avoid memory leaks on libvirt_virNodeGetMemoryStats (rhbz#770944)
- qemu: Use unlimited speed when migrating to file (rhbz#740099)
- qemu: Add support for domain cleanup callbacks (rhbz#795305)
- qemu: Avoid dangling migration-in job on shutoff domains (rhbz#795305)
- qemu: Add connection close callbacks (rhbz#795305)
- qemu: Make autodestroy utilize connection close callbacks (rhbz#795305)
- qemu: Avoid dangling migration-out job when client dies (rhbz#795305)
- python: Avoid memory leaks on libvirt_virNodeGetCPUStats (rhbz#770943)
- util: Consolidate duplicated error messages in virnetlink.c (rhbz#693842)
- python: Add virDomainGetCPUStats python binding API (rhbz#800366)
- snapshot: Add qemu capability for 'transaction' command (rhbz#782457)
- snapshot: Add atomic create flag (rhbz#782457)
- snapshot: Make offline qemu snapshots atomic (rhbz#782457)
- snapshot: Rudimentary qemu support for atomic disk snapshot (rhbz#782457)
- snapshot: Add support for qemu transaction command (rhbz#782457)
- snapshot: Wire up qemu transaction command (rhbz#782457)
- snapshot: Improve qemu handling of reused snapshot targets (rhbz#782457)
- Clarify virsh freecell manpage entry (rhbz#698521)
- Add support for event tray moved of removable disks (rhbz#575160)
- docs: Add documentation for new attribute tray of disk target (rhbz#575160)
- conf: Parse and for the tray attribute (rhbz#575160)
- qemu: Do not start with source for removable disks if tray is open (rhbz#575160)
- qemu: Prohibit setting tray status as open for block type disk (rhbz#575160)
- qemu: Update tray status while tray moved event is emitted (rhbz#575160)
- build: Fix incorrect enum declaration (rhbz#575160)
- spec: Add missed dependancy for numad (rhbz#769930)

* Mon Mar 19 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-6.el6
- cpu: Add new flag supported by qemu to the cpu definition (rhbz#767364)
- Added support for AMD Bulldozer CPU (rhbz#767364)
- graphics: Cleanup port policy (rhbz#801443)
- qemu: Reverse condition in qemuDomainCheckDiskPresence (rhbz#798938)
- cpu: Add cpu definition for Intel Sandy Bridge cpu type (rhbz#761005)
- cpu: Disable tsc-deadline feature not supported in qemu on RHEL 6.3 (rhbz#761005)
- qemu: Support numad (rhbz#769930)
- numad: Fix typo and warning (rhbz#769930)
- qemu: Use scsi-block for lun passthrough instead of scsi-disk (rhbz#782034)
- util: Make virDomainLeaseDefFree global (rhbz#802851)
- qemu: Don't 'remove' hostdev objects from domain if operation fails (rhbz#802851)
- util: Eliminate device object leaks related to virDomain*Remove*() (rhbz#802851)
- virsh: Fix invalid free (rhbz#803591)
- qemu: Eliminate memory leak in qemuDomainUpdateDeviceConfig (rhbz#802854)
- qemu: Support persistent hotplug of <hostdev> devices (rhbz#802856)
- qemu: Fix segfault when detaching non-existent network device (rhbz#802644)
- remote: Fix migration leaks (rhbz#798497)
- virsh: Trim aliases from -h output (rhbz#796526)
- Fix handling of blkio deviceWeight empty string (rhbz#804028)

* Tue Mar 13 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-5.el6
- Avoid global variable shadowed (rhbz#737726)
- Add nodeGetCPUmap() for getting available CPU IDs in a cpumap. (rhbz#737726)
- Qemu driver for virDomainGetCPUstats using cpuacct cgroup. (rhbz#737726)
- Cpu-stats command shows cpu statistics information of a domain. (rhbz#737726)
- Ensure max_id is initialized in linuxParseCPUmap() (rhbz#737726)
- rpc: Allow truncated return for virDomainGetCPUStats (rhbz#737726)
- qemu: Don't parse device twice in attach/detach (rhbz#770031)
- sanlock: Fix condition left crippled while debugging (rhbz#785736)
- sanlock: Use STREQ_NULLABLE instead of STREQ on strings that may be null (rhbz#785736)
- qemu: Fix startupPolicy for snapshot-revert (rhbz#798938)
- util: Don't overflow on errno in virFileAccessibleAs (rhbz#798938)
- blockResize: Add flag for bytes (rhbz#796526)
- docs: Use correct terminology for 1024 bytes (rhbz#796526)
- api: Add overflow error (rhbz#796526)
- util: New function for scaling numbers (rhbz#796526)
- xml: Share 'unit' in RNG (rhbz#796526)
- xml: Output memory unit for clarity (rhbz#796526)
- storage: Support more scaling suffixes (rhbz#796526)
- xml: Drop unenforced minimum memory limit from RNG (rhbz#796526)
- xml: Use long long internally, to centralize overflow checks (rhbz#796526)
- xml: Use better types for memory values (rhbz#796526)
- xml: Allow scaled memory on input (rhbz#796526)
- virsh: Add option aliases (rhbz#796526)
- virsh: Use option aliases (rhbz#796526)
- virsh: Add command aliases, and rename nodedev-detach (rhbz#796526)
- virsh: Improve storage unit parsing (rhbz#796526)
- virsh: Improve memory unit parsing (rhbz#796526)
- qemuBuildCommandLine: Don't add tlsPort if none set (rhbz#801443)
- Removed more AMD-specific features from cpu64-rhel* models (rhbz#768450)
- qemu: Support disk filenames with comma (rhbz#801970)
- cpustats: Collect VM user and sys times (miss python bindings) (rhbz#800366)
- cpustats: Report user and sys times (rhbz#800366)
- qemu: Fix (managed)save and snapshots with host mode CPU (rhbz#801160)
- qemu: Make block io tuning smarter (rhbz#770683)

* Tue Mar  6 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-4.el6
- Improve error reporting when virsh console is run without a TTY (rhbz#729940)
- pidfile: Make checking binary path in virPidFileRead optional (rhbz#729940)
- Add flags for virDomainOpenConsole (rhbz#729940)
- virsh: Add support for VIR_DOMAIN_CONSOLE_* flags (rhbz#729940)
- fdstream: Emit stream abort callback even if poll() doesnt. (rhbz#729940)
- fdstream: Add internal callback on stream close (rhbz#729940)
- util: Add helpers for safe domain console operations (rhbz#729940)
- qemu: Add ability to abort existing console while creating new one (rhbz#729940)
- Fixed service handling in specfile (rhbz#786770)
- qemu: Don't emit tls-port spice option if port is -1 (rhbz#798220)
- docs: Comments wiping supported algorithms (rhbz#725013)
- libvirt-guests: Add documentation and clean up to use virsh's improved list (rhbz#693758)
- libvirt-guests: Don't try to do a managed-save of transient guests (rhbz#693758)
- virsh: Enhance list command to ease creation of shell scripts (rhbz#693758)
- libvirt-guests: Check if URI is reachable before launching commands (rhbz#720691)
- hooks: Add support for capturing hook output (rhbz#795127)
- qemu: Add pre-migration hook (rhbz#795127)
- Support for cpu64-rhel* qemu cpu models (rhbz#768450)
- util: Add netlink event handling to virnetlink.c (rhbz#693842)
- Add de-association handling to macvlan code (rhbz#693842)
- qemu: Add ibmvscsi controller model (rhbz#782034)
- qemu: Add virtio-scsi controller model (rhbz#782034)
- conf: Add helper function to look up disk controller model (rhbz#782034)
- conf: Introduce new attribute for device address format (rhbz#782034)
- qemu: New cap flag to indicate if channel is supported by scsi-disk (rhbz#782034)
- qemu: Build command line for the new address format (rhbz#782034)
- tests: Add tests for virtio-scsi and ibmvscsi controllers (rhbz#782034)
- virsh: Two new helper functions for disk device changes (rhbz#713932)
- virsh: Use vshFindDisk and vshPrepareDiskXML in cmdDetachDisk (rhbz#713932)
- virsh: New command cmdChangeMedia (rhbz#713932)
- qemu: Require json for block jobs (rhbz#799055)
- qemu: Pass block pull backing file to monitor (rhbz#799055)
- virsh: Expose partial pull (rhbz#799055)
- libvirt-guests: Add parallel startup and shutdown of guests (rhbz#625362)
- qemu: Shared or readonly disks are always safe wrt migration (rhbz#751631)
- util: Eliminate crash in virNetDevMacVLanCreateWithVPortProfile (rhbz#693842)
- rpc: Fix client crash on connection close (rhbz#800185)
- conf: Add missing device types to virDomainDevice(Type|Def) (rhbz#691539)
- conf: Relocate virDomainDeviceDef and virDomainHostdevDef (rhbz#691539)
- conf: Reorder static functions in domain_conf.c (rhbz#691539)
- qemu: Rename virDomainDeviceInfoPtr variables to avoid confusion (rhbz#691539)
- conf: Add device pointer to args of virDomainDeviceInfoIterate callback (rhbz#691539)
- conf: Make hostdev info a separate object (rhbz#691539)
- conf: HostdevDef parse/format helper functions (rhbz#691539)
- conf: Give each hostdevdef a parent pointer (rhbz#691539)
- conf: Put subsys part of virDomainHostdevDef into its own struct (rhbz#691539)
- conf: Hostdev utility functions (rhbz#691539)
- qemu: Re-order functions in qemu_hotplug.c (rhbz#691539)
- qemu: Refactor hotplug detach of hostdevs (rhbz#691539)
- conf: Parse/format type='hostdev' network interfaces (rhbz#691539)
- qemu: Support type='hostdev' network devices at domain start (rhbz#691539)
- conf: Change virDomainNetRemove from static to global (rhbz#691539)
- qemu: Use virDomainNetRemove instead of inline code (rhbz#691539)
- qemu: Support type=hostdev network device live hotplug attach/detach (rhbz#691539)
- util: Two new pci util functions (rhbz#691539)
- util: Support functions for mac/portprofile associations on hostdev (rhbz#691539)
- util: Changes to support portprofiles for hostdevs (rhbz#691539)
- qemu: Install port profile and mac address on netdev hostdevs (rhbz#691539)
- Fix build after commit e3ba4025 (rhbz#693842)

* Tue Feb 28 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-3.el6
- storage: Allow runtime detection of scrub missing build dep (rhbz#725013)
- daemon: Plug memory leak (rhbz#795978)
- daemon: Fix logic bug with virAsprintf (rhbz#795978)
- util: Fix virFileAccessibleAs return path from parent (rhbz#795093)
- Add support for unsafe migration (rhbz#751631)
- virsh: Add --unsafe option to migrate command (rhbz#751631)
- Introduce virStorageFileIsClusterFS (rhbz#751631)
- qemu: Forbid migration with cache != none (rhbz#751631)
- qemu: Nicer error message on failed graceful destroy (rhbz#795656)
- Error out when using SPICE TLS with spice_tls=0 (rhbz#790436)
- Revert "spec: Mark directories in /var/run as ghosts" (rhbz#788985)
- Fixed URI parsing (rhbz#785164)
- virsh: Fix informational message in iface-bridge command (rhbz#797066)

* Tue Feb 21 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-2.el6
- qemu: Set capabilities based on supported monitor commands (rhbz#766958)
- qemu: Implement DomainPMSuspendForDuration (rhbz#766958)
- snapshot: Fix snapshot deletion use-after-free (rhbz#790744)
- storage: Allow runtime detection of scrub (rhbz#725013)
- qemu: Unlock monitor when connecting to dest qemu fails (rhbz#783968)
- qemu: Prevent crash of libvirtd without guest agent (rhbz#790745)
- python: Expose virDomain{G,S}etInterfaceParameters APIs in python binding (rhbz#770971)

* Tue Feb 14 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-1.el6
- Rebase to upstream 0.9.10 (rhbz#752433)
- Add support for sVirt in the LXC driver
- block rebase: add new API virDomainBlockRebase
- API: Add api to set and get domain metadata
- virDomainGetDiskErrors public API
- conf: add rawio attribute to disk element of domain XML
- Add new public API virDomainGetCPUStats()
- Introduce virDomainPMSuspendForDuration API
- resize: add virStorageVolResize() API
- Add a virt-host-validate command to sanity check HV config
- Add new virDomainShutdownFlags API
- QEMU guest agent support
- many improvements and bug fixes

* Wed Feb  8 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-0rc2.el6
- Rebase to upstream 0.9.10 release candidate 2 (rhbz#752433)

* Mon Feb  6 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.10-0rc1.el6
- Rebase to upstream 0.9.10 release candidate 1 (rhbz#752433)

* Tue Jan 17 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.9-2.el6
- Remove dependancy to dmidecode for non PC arches (rhbz#782444)

* Mon Jan  9 2012 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.9-1.el6
- Rebase to upstream 0.9.9 (rhbz#752433)

* Fri Dec 30 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.9-0rc1.el6
- Rebase to upstream 0.9.9 release candidate 1 (rhbz#752433)

* Mon Dec  8 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.8-1.el6
- Rebase to upstream 0.9.8 (rhbz#752433)
- some cleanups on the few remaining RHEL-only patches

* Mon Dec  5 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.8-0rc2.el6
- Rebase to upstream 0.9.8 release candidate 2 (rhbz#752433)

* Wed Nov  9 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-23.el6
- Revert "Set qemu migration speed unlimited when migrating to file" (rhbz#751900)

* Mon Nov  7 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-22.el6
- conf: Don't free uninitialized pointer (rhbz#751287)

* Wed Nov  2 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-21.el6
- docs: Document managed=yes of hostdev passthrough (rhbz#740686)
- ServerClient: Flush cached data (rhbz#748025)

* Wed Oct 26 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-20.el6
- qemu: Avoid leaking uninit data from hotplug to dumpxml (rhbz#747516)
- storage: Plug iscsi memory leak (rhbz#747516)

* Wed Oct 19 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-19.el6
- snapshot: Detect when qemu lacks disk-snapshot support (rhbz#747115)

* Mon Oct 17 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-18.el6
- virDomainCoreDump: Introduce VIR_DUMP_RESET flag (rhbz#632498)
- qemu: Implement VIR_DUMP_RESET (rhbz#632498)
- qemu: Check for domain being active on successful job acquire (rhbz#745734)
- Set to NULL members that have been freed to prevent crashes (rhbz#746075)
- virFDStream: Close also given errfd (fd leak) (rhbz#746075)
- qemu: Silence Coverity false positive (rhbz#739704)
- command: Avoid fd leak on failure (rhbz#739704)
- build: Add compiler attributes to virUUIDParse (rhbz#739704)
- qemu: Check for json allocation failure (rhbz#739704)
- qemu: Fix text block info parsing (rhbz#739704)
- storage: Plug memory leak on error (rhbz#739704)
- conf: Plug memory leak on error (rhbz#739704)
- qemu: Plug memory leak on migration (rhbz#739704)
- macvtap: Plug memory leak for 802.1Qbh (rhbz#739704)
- macvtap: Avoid invalid free (rhbz#739704)
- Update to require sanlock 1.8 for license compliance (rhbz#739518)
- events: Propose a separate lock for event queue (rhbz#743817)
- util: Make getaddrinfo failure nonfatal in virGetHostname (rhbz#738915)
- qemu: Make sure BeginJob is always followed by EndJob (rhbz#746268)
- pci: Fix pciDeviceListSteal on multiple devices (rhbz#733587)
- qemu: Do not reattach PCI device used by other domain when shutdown (rhbz#733587)
- qemu: Honor the orginal PCI dev properties when reattaching (rhbz#736214)
- daemon: Always advertise libvirtd service (rhbz#726616)

* Wed Oct 12 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-17.el6
- Fix deadlock when the RPC program is unknown (rhbz#743843)
- qemuDomainAttach: Initialize pidfile variable (rhbz#744548)
- storage: Do not use comma as seperator for lvs output (rhbz#727474)
- snapshot: Avoid accidental renames with snapshot-edit (rhbz#744724)

* Fri Oct  7 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-16.el6
- qemu: Enable multifunction for older qemu (rhbz#738388)
- qemu: Don't fail virDomainGetInfo if we can't update balloon info (rhbz#741217)
- qemu: Leave rerror policy at default when enospace is requested (rhbz#730909)
- snapshot: Fix virsh error message typo (rhbz#735457)
- snapshot: Let virsh edit disk snapshots (rhbz#744071)
- snapshot: Simplify redefinition of disk snapshot (rhbz#744071)

* Fri Oct  7 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-15.el6
- Add virFileLock and virFileUnlock APIs (rhbz#728153)
- Move pidfile functions into util/virpidfile.{c, h} (rhbz#728153)
- Introduce functions for checking whether a pidfile is valid (rhbz#728153)
- Add some APIs which use locking for crashsafe pidfile handling (rhbz#728153)
- Convert libvirtd to use crash-safe pidfile APIs (rhbz#728153)
- build: Fix recent build failures (rhbz#728153)
- daemon: Don't remove pidfiles in init scripts (rhbz#728153)
- daemon: Modify init script to detect upstart managed libvirtd (rhbz#728153)
- qemu: Check for outstanding async job too (rhbz#742277)
- qemu: Make PCI multifunction support more manual (rhbz#727530)
- network: Fill in bandwidth from portgroup for all forward modes (rhbz#743176)
- snapshot: Refactor virsh snapshot parent computation (rhbz#742410)
- snapshot: Better virsh handling of missing current, parent (rhbz#742410)
- qemu: Fix migration with dname (rhbz#740533)
- qemu: Correct misspelled 'enospc' option, and only use for werror (rhbz#730909)
- snapshot: Add REVERT_FORCE to API (rhbz#742615)
- snapshot: Use qemu-img on disks in use at time of snapshot (rhbz#742615)
- snapshot: Enforce REVERT_FORCE on qemu (rhbz#742615)
- init: Raise default system aio limits (rhbz#740899)

* Thu Sep 29 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-14.el6
- Fix synchronous reading of stream data (rhbz#741337)
- qemu: Add ability to set PCI device "rombar" on or off (rhbz#738095)
- virsh: Better document --copy-storage migrate options (rhbz#677220)
- virsh: Enhance documentation of commands starting jobs (rhbz#705237)
- qemu: Always remove domain object if MigratePrepare fails (rhbz#741251)
- security: Properly chown/label bidirectional and unidirectional fifos (rhbz#740478)
- qemu: Check domain status details when reconnecting monitor (rhbz#617890)
- qemu: Finish domain shutdown on reconnect (rhbz#617890)
- qemu: Avoid loop of fake reboots (rhbz#617890)
- qemu: Preserve fakeReboot flag in domain status (rhbz#617890)
- snapshot: Fix man page typos (rhbz#740686)
- docs: Document virsh nodedev-* commands (rhbz#740686)
- docs: Document node device XML (rhbz#740686)
- qemu: Add return value check (rhbz#739704)
- qemu: Check for ejected media during startup and migration (rhbz#725673)
- virsh: Update man page for cpu_shares parameter (rhbz#639591)
- virsh: Describe attach-interface parameter target (rhbz#698899)

* Mon Sep 26 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-13.el6
- Fix crash on events due to allocation errors (rhbz#737881)
- remote: Fix crash on OOM (rhbz#737881)
- Fix persistent migration config save (rhbz#738148)
- qemu: Transfer inactive XML among cookie (rhbz#738148)
- storage: Ensure the device path exists before refreshing disk pool (rhbz#611442)
- Store max migration bandwidth in qemuDomainObjPrivate struct (rhbz#740099)
- Save migration speed in qemuDomainMigrateSetMaxSpeed (rhbz#740099)
- Set qemu migration speed unlimited when migrating to file (rhbz#740099)
- Use max bandwidth from qemuDomainObjPrivate struct when migrating (rhbz#740099)
- build: Silence warning on 32-bit build (rhbz#740099)
- conf: Assign newDef of active domain as persistent conf if it is NULL (rhbz#728428)
- qemu: Avoid dereferencing a NULL pointer (rhbz#739704)
- sanlock: Fix memory leak (rhbz#739704)
- virsh: Fix regression in argv parsing (rhbz#740168)
- snapshot: Fix logic bug in qemu undefine (rhbz#735457)
- snapshot: Prepare to remove transient snapshot metadata (rhbz#735457)
- snapshot: Remove snapshot metadata on transient exit (rhbz#735457)
- snapshot: Also delete empty directory (rhbz#735457)
- virsh: Do not ignore the specified flags for cmdSaveImageDefine (rhbz#740508)
- selinux: Correctly report warning if virt_use_nfs not set (rhbz#589922)
- qemu: Properly hot-unplug drives (rhbz#696596)

* Tue Sep 20 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-12.el6
- selinux: Detect virt_use_nfs boolean set (rhbz#589922)
- virnetsocket: Pass KRB5CCNAME env variable (rhbz#737176)
- snapshot: Fix double free of qemuImgBinary (rhbz#737010)
- qemu_api: Modify apibuild.py to generate docs for QEMU APIs (rhbz#736040)
- qemu_api: Update Makefile for subdir docs (rhbz#736040)
- qemu_api: Add comments for API virDomainQemuMonitorCommand (rhbz#736040)
- qemu_api: Add override XML and C files for QEMU APIs (rhbz#736040)
- qemu_api: Update Py binding generator to generate files for QEMU APIs (rhbz#736040)
- qemu_api: Update Makefile to generate libvirtmod_qemu lib (rhbz#736040)
- qemu_api: Update libvirt spec file (rhbz#736040)
- Remove two references to files not generated (rhbz#736040)
- qemu_api: Doc improvements (rhbz#736040)
- python: Fix libvirt.py generation to include virterror info (rhbz#736040)
- snapshot: New APIs for inspecting snapshot object (rhbz#735457)
- snapshot: Use new API for less work (rhbz#735457)
- snapshot: ABI stability must include memory sizing (rhbz#735553)
- spec: Require augeas for sanlock (rhbz#738314)
- sanlock: Add missing test command in virt-sanlock-cleanup.in (rhbz#738534)
- snapshot: Tweak snapshot-create-as diskspec docs (rhbz#738411)
- qemu: Hold conn open for all threads started by qemuProcessReconnectAll (rhbz#738778)
- rpc: Convert unknown procedures to VIR_ERR_NO_SUPPORT (rhbz#738439)
- Prevent crash from dlclose() of libvirt.so (rhbz#739167)
- doc: Add statment about permissions needed to do a core dump (rhbz#738146)
- snapshot: Affect persistent xml after disk snapshot (rhbz#738676)
- snapshot: Allow disk snapshots of qcow2 disks (rhbz#738676)
- qemu: Prevent disk corruption on domain shutdown (rhbz#734773)
- qemu: Introduce shutdown reason for paused state (rhbz#734773)
- qemu: Fix shutoff reason when domain crashes (rhbz#739641)
- qemu: Properly detect crash of a rebooted domain (rhbz#739641)
- qemu: Avoid memory leak (rhbz#739704)
- remote: Avoid memory leak (rhbz#739704)
- util: Avoid memory leak (rhbz#739704)
- Fix memory leak parsing 'relabel' attribute in domain security XML (rhbz#739704)
- Don't leak memory if a cgroup is mounted multiple times (rhbz#739704)
- network: Eliminate potential memory leak on parse failure (rhbz#739704)
- virsh: doc: Fix supported driver types for attach-disk command (rhbz#738970)
- Do not log invalid operations in libvirtd logs (rhbz#590807)

* Thu Sep  8 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-11.el6
- blockinfo: Fix qemu regression in handling disk name (rhbz#736603)
- doc: Fix incorrect option in send-key (rhbz#736297)
- virsh: Fix typo in opts_send_key (rhbz#736297)
- rpc: Avoid memory leak on virNetTLSContextValidCertificate (rhbz#735650)
- tests: Avoid memory leak on testTLSSessionInit (rhbz#735650)
- qemu: Fix seamless SPICE migration with older qemu (rhbz#730753)
- snapshot: Fix regression with system checkpoints (rhbz#736682)

* Wed Sep  7 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-10.el6
- virterror: Fix error message for VIR_ERR_INVALID_ARG (rhbz#689388)
- remote: Refuse connecting to remote socket (rhbz#689388)
- Threadpool: Initialize new dynamic workers (rhbz#692663)

* Tue Sep  6 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-9.el6
- adds a missing patch in previous build (rhbz#735498)

* Tue Sep  6 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-8.el6
- qemu: Fix a regression of domain save (rhbz#735011)
- virsh: Improve send-key documentation (rhbz#699847)
- start: Allow discarding managed save (rhbz#730750)
- virsh: Support 'virsh start --force-boot' on older servers (rhbz#730750)
- maint: Fix comment typos (rhbz#730750)
- qemu: Refactor file opening (rhbz#730750)
- qemu: Detect incomplete save files (rhbz#730750)
- virsh: Avoid memory leak on cmdVolCreateAs (rhbz#735008)
- snapshot: Fix corner case on OOM during creation (rhbz#674537)
- Ensure stream is aborted when exiting console (rhbz#731673)
- following for (rhbz#731583, rhbz#731579, rhbz#731584, rhbz#731673):
- Ensure client streams are closed when marking a client for close
- Fix race condition in abort of stream
- Tweak debugging message in RPC client code
- Don't attempt to read from a stream if it is closed
- Ensure async packets never get marked for sync replies
- Ignore unused streams in virStreamAbort
- rpc: Don't close connection if program is unknown
- rpc: Fix a typo in debugging log in virNetServerProgramSendStreamData
- stream: Remove redundant reference to client while sending stream data
- Fix memory leak dispatching domain events
- Avoid use-after-free on streams, due to message callbacks
- Fix tracking of RPC messages wrt streams
- Fix parted sector size assumption (rhbz#735441)
- Fix incorrect path length check in sanlock lockspace setup (rhbz#735443)
- Fix sanlock socket security labelling (rhbz#735442)
- Remove bogus virSecurityManagerSetProcessFDLabel method (rhbz#735442)
- security: Fix build (rhbz#735442)
- Fix keymap used to talk with QEMU (rhbz#632499)
- virsh: Fix snapshot-create-as to handle arbitrary names (rhbz#735495)
- virsh: Add virsh snapshot-current --name (rhbz#735495)
- virsh: Add snapshot-parent (rhbz#735495)
- virsh: Don't reject undefine on active domain (rhbz#735495)
- virsh: Fix logic bug (rhbz#735495)
- virsh: Fix dead store (rhbz#735495)
- virsh: Tweak misleading wording (rhbz#735495)
- virsh: Concatenate qemu-monitor-command arguments (rhbz#735495)
- maint: Treat more libxml2 functions as free-like (rhbz#735495)
- xml: Add another convenience function (rhbz#735495)
- maint: Simplify lots of libxml2 clients (rhbz#735495)
- virsh: Add list --managed-save (rhbz#735495)
- virsh: Prefer unsigned flags (rhbz#735495)
- snapshot: Add snapshot-list --parent to virsh (rhbz#735495)
- qemu: Allow to undefine a running domain (rhbz#735498)
- test: Allow to undefine a running domain (rhbz#735498)
- build: Fix typo in recent test patch (rhbz#735498)
- test: Rewrite test to match change in behavior (rhbz#735498)
- virsh: Properly interleave shared stdout and stderr (rhbz#735498)
- snapshot: Better events when starting paused (rhbz#733762)
- snapshot: Fine-tune ability to start paused (rhbz#733762)
- snapshot: Expose --running and --paused in virsh (rhbz#733762)
- snapshot: Fine-tune qemu saved images starting paused (rhbz#733762)
- snapshot: Improve reverting to qemu paused snapshots (rhbz#733762)
- snapshot: Properly revert qemu to offline snapshots (rhbz#733762)
- snapshot: Fine-tune qemu snapshot revert states (rhbz#733762)
- snapshot: Properly revert qemu to offline snapshots (rhbz#733762)
- snapshot: Fine-tune qemu snapshot revert states (rhbz#733762)
- snapshot: Speed up snapshot location (rhbz#733529)
- snapshot: Avoid crash when deleting qemu snapshots (rhbz#733529)
- snapshot: Track current domain across deletion of children (rhbz#733529)
- snapshot: Simplify acting on just children (rhbz#733529)
- snapshot: Allow deletion of just snapshot metadata (rhbz#735457)
- snapshot: Let qemu discard only snapshot metadata (rhbz#735457)
- snapshot: Identify which snapshots have metadata (rhbz#735457)
- snapshot: Reflect new dumpxml and list options in virsh (rhbz#735457)
- snapshot: Identify qemu snapshot roots (rhbz#735457)
- snapshot: Allow recreation of metadata (rhbz#735457)
- snapshot: Refactor virsh snapshot creation (rhbz#735457)
- snapshot: Improve virsh snapshot-create, add snapshot-edit (rhbz#735457)
- snapshot: Add qemu snapshot creation without metadata (rhbz#735457)
- snapshot: Add qemu snapshot redefine support (rhbz#735457)
- vbox, xenapi: Add virDomainUndefineFlags (rhbz#735457)
- snapshot: Prevent stranding snapshot data on domain destruction (rhbz#735457)
- snapshot: Teach virsh about new undefine flags (rhbz#735457)
- snapshot: Refactor some qemu code (rhbz#735457)
- snapshot: Cache qemu-img location (rhbz#735457)
- snapshot: Support new undefine flags in qemu (rhbz#735457)
- snapshot: Prevent migration from stranding snapshot data (rhbz#735457)
- snapshot: Refactor domain xml output (rhbz#735553)
- snapshot: Allow full domain xml in snapshot (rhbz#735553)
- snapshot: Correctly escape generated xml (rhbz#735553)
- snapshot: Update rng to support full domain in xml (rhbz#735553)
- snapshot: Store qemu domain details in xml (rhbz#735553)
- schedinfo: Update man page about virsh schedinfo command (unknown)
- snapshot: Additions to domain xml for disks (rhbz#638510)
- snapshot: Reject transient disks where code is not ready (rhbz#638510)
- snapshot: Introduce new deletion flag (rhbz#638510)
- snapshot: Expose new delete flag in virsh (rhbz#638510)
- snapshot: Allow halting after snapshot (rhbz#638510)
- snapshot: Expose halt-after-creation in virsh (rhbz#638510)
- snapshot: Support extra state in snapshots (unknown)
- snapshot: Add <disks> to snapshot xml (rhbz#638510)
- snapshot: Also support disks by path (rhbz#638510)
- snapshot: Add virsh domblklist command (rhbz#638510)
- snapshot: Add flag for requesting disk snapshot (rhbz#638510)
- snapshot: Wire up disk-only flag to snapshot-create (rhbz#638510)
- snapshot: Reject unimplemented disk snapshot features (rhbz#638510)
- snapshot: Make it possible to audit external snapshot (rhbz#638510)
- snapshot: Wire up new qemu monitor command (rhbz#638510)
- snapshot: Wire up live qemu disk snapshots (rhbz#638510)
- snapshot: Use SELinux and lock manager with external snapshots (rhbz#638510)
- daemon: Create priority workers pool (rhbz#692663)
- qemu: Introduce job queue size limit (rhbz#692663)
- qemu: Deal with stucked qemu on daemon startup (rhbz#692663)

* Wed Aug 31 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-7.el6
- qemu: Properly label outgoing pipe for tunneled migration (rhbz#733998)
- snapshot: Forbid snapshot on autodestroy domain (rhbz#733806)

* Fri Aug 26 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-6.el6
- daemon: Move TLS initialization to virInitialize (rhbz#732893)
- Fix command test wrt gnutls initialize & fix debugging (rhbz#732893)
- qemu: Init reattaching related members pciDevice before reattach (rhbz#728203)
- qemu: error if qemu monitor command not found for BlockJob (rhbz#727502)
- virsh: error if specified bandwidth is invalid for blockjob (rhbz#727502)
- util: Only fchown newly created files in virFileOpenAs (rhbz#534010)
- screenshot: Implement multiple screen support (rhbz#710489)
- security: Rename SetSocketLabel APIs to SetDaemonSocketLabel (rhbz#731243)
- security: Introduce SetSocketLabel (rhbz#731243)
- qemu: Correctly label migration TCP socket (rhbz#731243)
- snapshot: Don't leak resources on qemu snapshot failure (rhbz#733499)
- Fix memory leak while scanning snapshots (rhbz#674537)
- qemu: Minor formatting cleanup (rhbz#674537)
- Swap virDomain and virDomainSnapshot declaration (rhbz#674537)
- snapshot: Only pass snapshot to qemu command line when reverting (rhbz#674537)
- snapshot: Track current snapshot across restarts (rhbz#674537)
- send-key: Fix scan keycode map (rhbz#733597)

* Mon Aug 22 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-5.el6
- patch problem for seamless SPICE migration (rhbz#730753)
- macvtap: Fix getPhysfn to get the PF of a direct attach network interface (rhbz#732082)
- SSL spice session can't be kept during migration (rhbz#729874)
- Storage driver should flush host cache after cloning volumes (rhbz#689416)
- Documentation for CFS bandwidth limiting cgroup (rhbz#692769)
- libvirt error message should show the uri content but not (null) (rhbz#730244)
- libvirtd.conf error causes libvirtd to exit silently (rhbz#728654)

* Mon Aug 15 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-4.el6
- Bugfix: Check stdoutWatch before removing the handler. (rhbz#730600)
- daemon: Fix regression of libvirtd reloading support (rhbz#730428)
- libvirtd.init.in: Stop/restart() - wrong return value in case of failure (rhbz#730510)
- Add API for duplicating a socket/client file descriptor (rhbz#720269)
- Add backlog parameter to virNetSocketListen (rhbz#720269)
- Support changing UNIX socket owner in virNetSocketNewListenUNIX (rhbz#720269)
- qemu: Refactor do{Tunnel, Native}Migrate functions (rhbz#720269)
- qemu: Use virNetSocket for tunneled migration (rhbz#720269)
- qemu: Use fd: protocol for migration (rhbz#720269)
- qemu: Support event_idx parameter for virtio disk and net devices (rhbz#725448)
* Mon Aug 15 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-3.el6
- Fix large files support (rhbz#728992)
- qemu: Avoid overwriting errors from virGetHostname (rhbz#729567)
- qemu: Fix -chardev udp if parameters are omitted (rhbz#689761)
- managedsave: Prohibit use on transient domains (rhbz#729714)
- nwfilter: Tolerate disappearing interfaces while instantiating filter (rhbz#729945)
- docs: Describe new virtual switch configuration in network XML docs (rhbz#643947)
- storage: Directory shouldn't be listed as type 'file' (rhbz#727088)
- virsh: Add dir type for listing volumes with vol-list (rhbz#727088)
- qemu: Avoid crash on process attach (rhbz#730615)

* Tue Aug  9 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-2.el6
- daemon: Unlink unix socket paths on shutdown (rhbz#725702)
- rpc:Fix sasl session relocking intead of unlocking it (rhbz#729198)
- network: Eliminate lag in updating dnsmasq hosts files (rhbz#727982)
- Don't mount /dev for application containers (rhbz#728835)
- support connected parameter in set_password (rhbz#707212)

* Wed Aug  3 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-1.el6
- Rebased to upstream 0.9.4 (rhbz#705814)
- The rebase also fixes the following bugs:
    rhbz#634653, rhbz#707212, rhbz#722806, rhbz#723862, rhbz#726304,
    rhbz#726398, rhbz#727047, rhbz#727094

* Fri Jul 29 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-0rc2.el6
- rebased to upstream 0.9.4 release candidate 2 (rhbz#705814)
- the rebase also fixes the following bugs:
    rhbz#667624, rhbz#669586, rhbz#682084, rhbz#707155, rhbz#707212,
    rhbz#725322, rhbz#725935, rhbz#725950

* Fri Jul 29 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-0rc1.1.el6
- add a fix for a refcounting bug leading to a crash (rhbz#723811)

* Tue Jul 26 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.4-0rc1.el6
- rebased to upstream 0.9.4 release candidate 1 (rhbz#705814)
- the rebase also fixes the following bugs:
    rhbz#603039, rhbz#632499, rhbz#632760, rhbz#643947, rhbz#678027,
    rhbz#697742, rhbz#697841, rhbz#704836, rhbz#707530, rhbz#720350,
    rhbz#720889, rhbz#721335, rhbz#722862

* Tue Jul 26 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.3-8.el6
- libvirt crash when running domains and vdsm is restarted (rhbz#723811)
- connect to hypervisor with unconfigured tls/tcp connection pbm (rhbz#723442)
- virsh list produced segmentation fault when libvirtd is not up (rhbz#723843)
- clientcert.pem validation failure cause libvirtd crash (rhbz#723881)

* Wed Jul 20 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.3-7.el6
- Fix TLS certificate checking problems (rhbz#723447)

* Wed Jul 20 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.3-6.el6
- Fix migration with TLS bugs (rhbz#722738 and rhbz#722748)
- assorted small fixes from upstream

* Fri Jul 15 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.3-5.el6
- Fix migrating domain error (rhbz#721411)

* Fri Jul 15 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.3-4.el6
- storage: Avoid memory leak on metadata fetching (rhbz#707155)
- graphics: Add support for action_if_connected in qemu (rhbz#707212)
- qemu: Save domain status ASAP after creating qemu process (rhbz#707894)
- bios: Add support for SGA (rhbz#711598)
- pci: Initialize state values on reattach (rhbz#713697)
- Keep consistence between code and doc on log level and usage (rhbz#716888)

* Thu Jul 14 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.3-3.el6
- util: Avoid duplicating virFileOpenAsNoFork in virFileOpenAs (rhbz#707257)

* Mon Jul 11 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.3-2.el6
- Fix mistaken order of server cert/key parameters in constructor (rhbz#719838)
- qemu: Don't chown files on NFS share if dynamic_ownership is off (rhbz#716478)
- util: Don't try to fchown files opened as non-root (rhbz#707257)

* Mon Jul  4 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.3-1.el6
- Rebased to upstream 0.9.3 (rhbz#705814)
- The rebase also fixes the following bugs:
    rhbz#591974, rhbz#632499, rhbz#641087, rhbz#664629, rhbz#679668,
    rhbz#682121, rhbz#693648, rhbz#693650, rhbz#693661, rhbz#698340,
    rhbz#698825, rhbz#698861, rhbz#701394, rhbz#707439, rhbz#707530,
    rhbz#715355, rhbz#716826, rhbz#717203, rhbz#718143, rhbz#712050,
    rhbz#715184

* Thu Jun 30 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.3-0rc2.el6
- Rebased to upstream 0.9.3 prerelease 2 (rhbz#705814)

* Mon Jun 20 2011 Daniel Veillard <veillard@redhat.com> - libvirt-0.9.2-1.el6
- Rebased to upstream 0.9.2 (rhbz#705814)
- The rebase also fixes the following bugs:
    rhbz#569567, rhbz#691830, rhbz#607526, rhbz#609650, rhbz#632495,
    rhbz#640603, rhbz#658713, rhbz#669549, rhbz#677229, rhbz#678548,
    rhbz#640603, rhbz#682237, rhbz#683005, rhbz#684848, rhbz#688859,
    rhbz#690695, rhbz#692355, rhbz#693203, rhbz#694516, rhbz#697650,
    rhbz#698133, rhbz#702044, rhbz#704124, rhbz#704144, rhbz#705405,
    rhbz#706869, rhbz#706883, rhbz#706966, rhbz#707173, rhbz#707257,
    rhbz#707298, rhbz#709576, rhbz#709776, rhbz#710150, rhbz#711151

* Thu May 19 2011 Jiri Denemark <jdenemar@redhat.com> - libvirt-0.9.1-1.el6
- Rebased to upstream 0.9.1 (rhbz#705814)
- The rebase also fixes the following bugs:
    rhbz#587276, rhbz#591058, rhbz#592170, rhbz#598792, rhbz#673814,
    rhbz#677228, rhbz#681458, rhbz#682237, rhbz#692745, rhbz#693932,
    rhbz#694382, rhbz#695653, rhbz#698071, rhbz#698197, rhbz#698208,
    rhbz#698490, rhbz#701305

* Mon Apr 18 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-18.el6
- network: Fix NULL dereference during error recovery (rhbz#696660)
- virsh: Fix regression in parsing optional integer (rhbz#693963)
- util: Fix crash when removing entries during hash iteration (rhbz#693385)
- Experimental libvirtd upstart job (rhbz#678084)

* Wed Apr 13 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-17.el6
- Don't return an error on failure to create blkio controller (rhbz#689030)
- Fix possible infinite loop in remote driver (rhbz#691514)
- qemu: Remove the managed state file only if restoring succeeded (rhbz#692998)
- docs: Tweak virsh restore warning (rhbz#692998)

* Wed Apr  6 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-16.el6
- nwfilter: Enable rejection of packets (rhbz#681948)
- Revert all previous error log priority hacks (rhbz#587603)
- Filter out certain expected error messages from libvirtd (rhbz#587603)
- qemu: Unlock qemu driver before return from domain save (rhbz#688774)
- Do not send monitor command after monitor meet error (rhbz#688774)
- qemu: Ignore libvirt debug messages in qemu log (rhbz#681492)
- virsh: Fix memtune's help message for swap_hard_limit (rhbz#680190)
- virsh: Fix documentation for memtune command (rhbz#680190)
- docs: Fix typo (rhbz#680190)
- Fix typo in systemtap tapset directory name (rhbz#693701)
- qemu: Ignore unusable binaries (rhbz#676563)
- qemu: Support for overriding NPROC limit (rhbz#674602)

* Tue Mar 29 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-15.el6
- Fix return value for virJSONValueFromString if it fails (rhbz#688723)
- Fix positioning to end of qemu log file (rhbz#689986)
- Initialization error of qemuCgroupData in Qemu host usb hotplug (rhbz#690183)
- 8021Qbh: Use preassociate-rr during the migration prepare stage (rhbz#684870)
- Make error reporting in libvirtd thread safe (rhbz#689374)
- Add missing dependencies (rhbz#690022)
- Fix restoring a compressed save image (rhbz#691034)
- Fix label restore bugs in qemu driver (rhbz#690737)

* Tue Mar 22 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-14.el6
- Fix delayed events when SASL is active (rhbz#624252)
- Fix ref-counting bugs (rhbz#688774)
- Log an error if on failure to connect to netlink socket (rhbz#689001)
- Log error and abort network startup when radvd isn't found (rhbz#688957)
- Add PCI sysfs reset access rights to qemu (rhbz#689002)
- Fix regression with qemu:///session URI (rhbz#684655)
- Avoid leaking PCI config fd into qemu (rhbz#687993)

* Wed Mar 16 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-13.el6
- Properly report error in virConnectDomainXMLToNative (CVE-2011-1146)
- Handle DNS over IPv6 (rhbz#687896)
- Start dnsmasq even if no dhcp ranges/hosts are specified (rhbz#687291)
- Use a separate dhcp leases file for each network (rhbz#687551)
- Fix a possible crash in storage driver (rhbz#684712)

* Tue Mar 15 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-12.el6
- Fix vram settings for qxl graphics (rhbz#673578)
- Free stream when domain shuts down while its console is open (rhbz#682741)
- Use hardcoded python path in libvirt.py (rhbz#684204)
- Add missing checks for read only connections (CVE-2011-1146)
- Eliminate potential null pointer deref when auditing macvtap devices (rhbz#642785)
- Insert error messages to avoid a quiet abortion of commands (rhbz#605660)

* Thu Mar 10 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-11.el6
- Support vram specification for qxl graphics (rhbz#673578)
- Fix parsing int options in virsh (rhbz#639587)
- Use -o encryption=on instead of -e for qemu-img (rhbz#676984)
- Support domain snapshots with current QMP (rhbz#589076)
- Update auditing support (rhbz#642785)
- Only request sound cgroup ACL when required (rhbz#680398)
- Allow fine-tuning of device ACL permissions (rhbz#683163)
- Support vhost in attach-interface (rhbz#683276)
- Don't request cgroup ACL access for /dev/net/tun (rhbz#683305)

* Mon Mar 07 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-10.el6
- Fix deadlock caused by a fix for rhbz#670848

* Fri Mar 04 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-9.el6
- Reorder nwfilter match extensions relative to state match (rhbz#678139)
- Avoid overwriting error message in qemu driver (rhbz#678870)
- Allow removing hash entries in virHashForEach (rhbz#681459)
- Avoid double close on qemu domain restore (rhbz#672725)
- Fix DomainObj refcounting/hashtable races in qemu driver (rhbz#670848)
- Fix several memory leaks (rhbz#682249)

* Thu Feb 24 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-8.el6
- Fix --all flag of virsh freecell to really show all cells (rhbz#653530)
- Add txmode attribute to interface XML for virtio backend (rhbz#629662)
- Give each virtual network bridge its own fixed MAC address (rhbz#609463)
- Fix virsh snapshot-list with --quiet option (rhbz#678833)
- Delay IFF_UP'ing 802.1Qbh interface until migration final stage (rhbz#678826)
- Fix several memory bugs (rhbz#679164)
- Fix virt-pki-validate when CERTTOOL is missing (rhbz#679153)
- Fix memory corruption in virFileAbsPath (rhbz#680281)

* Thu Feb 17 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-7.el6
- Properly escape special characters in domain names (rhbz#676908)
- Fix enum type declaration (rhbz#628940)
- Fix cleanup on VM state after failed QEMU startup (rhbz#673588)
- Fix XML generation for smartcards (rhbz#677308)
- Ignore failure of "qemu -M ?" on older qemu (rhbz#676563)
- Fix typo in setting up SPICE passwords (rhbz#677709)
- Avoid NULL dereference in virDomainMemoryStats (rhbz#677484)
- Avoid NULL dereference on error in qemu driver (rhbz#677493)
- Fix error message when saving a shutoff domain (rhbz#677547)
- Create enough volumes for mpath pool (rhbz#677231)
- Allow to delete device mapper disk partition (rhbz#611443)

* Fri Feb 11 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-6.el6
- Fix typo in parsing of spice 'auth' data (rhbz#676374)
- Fix attach-interface regression (rhbz#676686)
- Block I/O tunables via blkio cgroups controller (rhbz#632492)
- Support SCSI RAID type & lower log level for unknown types (rhbz#675771)
- Only initialize/cleanup libpciaccess once (rhbz#675698)
- Imprint all logs with version + package build information (rhbz#673226)

* Thu Feb 04 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-5.el6
- Docs for customizable x509 certificate paths for client (rhbz#629510)
- Fix tests for VNC over a unix domain socket (rhbz#651415)
- Fix problems with peer-to-peer migration (rhbz#673434)
- Fix tunneled migration broken since 0.8.7-2 (rhbz#672199)
- Update docs for cpu_shares setting (rhbz#641187)
- Fix possible hang if SASL is used (rhbz#672226)
- Cancel migration in progress when virsh gets Ctrl-C (rhbz#635353)
- Enhance virsh migrate command (rhbz#619039)
- Support for specifying AIO mode for qemu disks (rhbz#591703)
- Don't leave domain paused after restore (rhbz#670278)
- Fix possible deadlock/crash in qemu driver (rhbz#673588)
- Add shortcut for qemu HMP pass through (rhbz#628940)
- Fix error message when attach device fails (rhbz#675030)
- Support for booting from assigned PCI devices (rhbz#646895)
- Improve handling of unlimited value for memory tunables (rhbz#669069)
- Add smartcard support (rhbz#641834)
- Remove some RHEL-specific patches which are no longer required (rhbz#653985)
- Support for disabling/enabling KSM per domain (rhbz#635419)
- Add --all flag to virsh freecell command (rhbz#653530)

* Thu Jan 27 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-4.el6
- Fix event-handling data race (rhbz#671567)
- Add support for VNC over a unix domain socket (rhbz#651415)
- Support intel 'ich6' model (rhbz#648486)
- Do not use virtio-serial port 0 for generic ports (rhbz#670394)
- Set SELinux context label of pipes used for qemu migration (rhbz#667756)
- Support customizable x509 certificate paths for client (rhbz#629510)
- Round up capacity for LVM volume creation (rhbz#670529)
- Show error prompt when trying to managed save a shutoff domain (rhbz#672449)
- Report more proper error for unsupported graphics (rhbz#671319)
- Expand the man page text for virsh setmaxmem (rhbz#622534)
- Fix event-handling allocation crash (rhbz#671564)
- Require --mac to avoid detach-interface ambiguity (rhbz#671050)

* Thu Jan 20 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-3.el6
- Report error if invalid type specified for character device (rhbz#638968)
- Improve log for domain related APIs (rhbz#640202)
- Reject SDL graphic if it's not supported by qemu (rhbz#633326)
- Don't lose track of events when callbacks are slow (rhbz#624252)
- Fail if per-device boot is used but deviceboot is not supported (rhbz#670399)
- Avoid sending STOPPED event twice (rhbz#666158)
- Fix issues introduced by dependency patches for rhbz#646895

* Mon Jan 17 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-2.el6
- Fix spec file which was not fully rebased to 0.8.7 (rhbz#653985, rhbz#660706)
- Skip IB700 watchdog device when assigning PCI slots (rhbz#667091)
- Improve error reporting when parsing dhcp info (rhbz#653300)
- Don't chown saved image back to root if dynamic_ownership=0 (rhbz#661720)
- Fix core dumps if unix_sock_group is set (rhbz#623166)
- Add support for Westmere CPU model (rhbz#656248)
- Add XML config switch to enable/disable vhost-net support (rhbz#643050)
- Enable tuning of qemu network tap device "sndbuf" size (rhbz#665293)
- Support for explicit boot device ordering (rhbz#646895)
- Avoid qemu holding migration fd indefinitely (rhbz#620363)

* Sun Jan 09 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.7-1.el6
- Rebased to upstream 0.8.7 (rhbz#653985)
- The following bugs got fixed by the rebase:
    rhbz#586124, rhbz#595350, rhbz#611793, rhbz#611822, rhbz#617439,
    rhbz#620363, rhbz#626873, rhbz#627143, rhbz#628772, rhbz#639595,
    rhbz#639603, rhbz#656795, rhbz#658657, rhbz#659855, rhbz#660706,
    rhbz#664406, rhbz#665446

* Thu Dec 23 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.6-1.el6
- Rebased to upstream 0.8.6 (rhbz#653985)

* Fri Dec 10 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.1-29.el6
- spec file cleanups (rhbz#649523)
- Fix deadlock on concurrent multiple bidirectional migration (rhbz#659310)
- Fix funny error in clock-variable (rhbz#660194)
- Export host information through SMBIOS to guests (rhbz#526224)
- Ensure device is deleted from guest after unplug (rhbz#644015)
- Distinguish between QEMU domain shutdown and crash (rhbz#656845)

* Mon Nov 29 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.1-28.el6
- Fix JSON migrate_set_downtime command (rhbz#561935)
- Make SASL work over UNIX domain sockets (rhbz#641687)
- Let qemu group look below /var/lib/libvirt/qemu/ (rhbz#643407)
- Fix save/restore on root_squashed NFS (rhbz#643884)
- Fix race on multiple migration (rhbz#638285)
- Export host information through SMBIOS to guests (rhbz#526224)
- Support forcing a CDROM eject (rhbz#626305)

* Wed Aug 18 2010 Daniel Veillard <veillard@redhat.com> - 0.8.1-27
- build -26 hit a miscompilation error c.f. 624895 drop %{?_smp_mflags}
- Resolves: rhbz#620847
- Resolves: rhbz#623877

* Tue Aug 17 2010 Dave Allan <dallan@redhat.com> - 0.8.1-26
- Fix problem with capabilities XML generation
- Resolves: rhbz#620847
- Correctly reserve and release PCI slots
- Resolves: rhbz#623877

* Sun Aug 15 2010 Daniel Veillard <veillard@redhat.com> - 0.8.1-25
- fix PXE booting on the virtual network
- Resolves: rhbz#623951
- fix tunelled migration
- Resolves: rhbz#624062

* Thu Aug 12 2010 Daniel Veillard <veillard@redhat.com> - 0.8.1-24
- do not call balloon info command if balloon is desactivated
- Resolves: rhbz#617286

* Wed Aug 11 2010 Daniel Veillard <veillard@redhat.com> - 0.8.1-23
- give a way to desactivate memory balloon support
- Resolves: rhbz#617286

* Tue Aug 10 2010 Dave Allan <dallan@redhat.com> - 0.8.1-22
- Mitigate asynchronous device_del
- Resolves: rhbz#609437
- Fix PCI address allocation
- Resolves: rhbz#618484
- Make nodeinfo skip offline CPUs
- Resolves: rhbz#622515

* Tue Aug  3 2010 Dave Allan <dallan@redhat.com> - 0.8.1-21
- Fix multiple PCI device assignment bugs
- Resolves: rhbz#617116
- Fix the ACS checking in the PCI code
- Resolves: rhbz#615218
- Disable boot=on when not using KVM
- Resolves: rhbz#594068
- Don't leak delay string when freeing virInterfaceBridgeDefs
- Resolves: rhbz#620837

* Wed Jul 28 2010 Dave Allan <dallan@redhat.com> - 0.8.1-20
- Fix error message in guests init script when libvirtd isn't installed
- Resolves: rhbz#617527

* Tue Jul 27 2010 Dave Allan <dallan@redhat.com> - 0.8.1-19
- Add character device backend activating QEMU internal spice agent
- Resolves: rhbz#615757
- Make libvirt-guests initscript Fedora compliant
- Resolves: rhbz#617300

* Thu Jul 22 2010 Daniel Veillard <veillard@redhat.com> - 0.8.1-18
- Fix patch for PIIX3 slot 1 reservation, in case it's already reserved
- Resolves: rhbz#592026

* Wed Jul 21 2010 Dave Allan <dallan@redhat.com> - 0.8.1-17
- Set a stable & high MAC addr for guest TAP devices
- Resolves: rhbz#616517
- Fix bogus commit of -16 patches
- Related: rhbz#592026
- Related: rhbz#599590

* Wed Jul 21 2010 Dave Allan <dallan@redhat.com> - 0.8.1-16
- Make PCI device ordering consistent with older releases
- Resolves: rhbz#592026
- Fix libvirtd hang during concurrent bi-directional migration
- Resolves: rhbz#599590

* Wed Jul 14 2010 Dave Allan <dallan@redhat.com> - 0.8.1-15
- Add iptables rule to fixup DHCP response checksum
- Resolves: rhbz#612588

* Tue Jul 13 2010 Dave Allan <dallan@redhat.com> - 0.8.1-14
- Support virtio disk hotplug in JSON mode
- Resolves: rhbz#573946
- Fix QEMU monitor JSON crash
- Resolves: rhbz#604585
- CVE-2010-2237 CVE-2010-2238 CVE-2010-2239
- Resolves: rhbz#607817
- CVE-2010-2242 Apply a source port mapping to virtual network masquerading
- Resolves: rhbz#608049
- Fix hang if QEMU exits (almost) immediately
- Resolves: rhbz#610056
- Support new CPU models provided by qemu-kvm
- Resolves: rhbz#605830
- Fix comparison of two host CPUs
- Resolves: rhbz#611401
- Don't mess with the CPU returned by arch driver
- Resolves: rhbz#613014
- Fail when CPU type cannot be detected from XML
- Resolves: rhbz#613760
- Use -nodefconfig when probing for CPU models
- Resolves: rhbz#613764
- cpuCompare: Fix crash on unexpected CPU XML
- Resolves: rhbz#613765
- Properly report failure to create raw storage volume files
- Related: rhbz#547543
- Fix IOErrorReasonCallback python bindings
- Related: rhbz#586353
- Parthelper: canonicalize block device paths
- Related: rhbz#593785

* Wed Jun 30 2010 Dave Allan <dallan@redhat.com> - 0.8.1-13
- Don't invoke destroy callback from qemuMonitorOpen() failure paths (v2)
- Related: rhbz#609060

* Tue Jun 29 2010 Dave Allan <dallan@redhat.com> - 0.8.1-12
- Don't invoke destroy callback from qemuMonitorOpen() failure paths
- Resolves: rhbz#609060
- virFileResolveLink: guarantee an absolute path
- Resolves: rhbz#608092
- SPICE patches have translatable strings without format args
- Resolves: rhbz#608917
- No way to pass disk format type to pool-define-as nor pool-create-as
- Resolves: rhbz#597790
- Fix enforcement of direction of traffic for rules describing incoming traffic
- Resolves: rhbz#606889
- Clarify virsh help pool-create-as text
- Resolves: rhbz#609044

* Mon Jun 28 2010 Dave Allan <dallan@redhat.com> - 0.8.1-11
- Do not block during incoming migration
- Resolves: rhbz#579440
- Label serial devices
- Resolves: rhbz#585249
- parthelper: fix compilation without optimization
- Related: rhbz#593785
- Fix name/UUID uniqueness checking in storage/network
- Resolves: rhbz#593951
- Don't squash file permissions when migration fails
- Resolves: rhbz#607922
- Properly handle 'usbX' sysfs files
- Resolves: rhbz#603867
- add pool support to vol-key command & improve vol commands help
- Resolves: rhbz#598365
- document attach-disk better
- Resolves: rhbz#601143
- Config iptables to allow tftp port if network <tftp> element exists
- Resolves: rhbz#607294
- Fix failure to generate python bindings when libvirt.h.in is updated
- Related: rhbz#589465
- Allow all interface names
- Resolves: rhbz#593907
- Fix nodedevice refcounting
- Resolves: rhbz#608753
- Move nwfilter functions inside extern C and fix a locking bug
- Resolves: rhbz#597391
- Fix failure to restore qemu domains with selinux enforcing
- Resolves: rhbz#590975
- Check for presence of qemu -nodefconfig option before using it
- Resolves: rhbz#608859

* Mon Jun 21 2010 Dave Allan <dallan@redhat.com> - 0.8.1-10
- Add multiIQN XML output
- Resolves: rhbz#587700
- Fix udev node device parent-child device relationships
- Resolves: rhbz#593995
- Fix leaks in udev device add/remove
- Resolves: rhbz#595490
- Fix device destroy return value
- Resolves: rhbz#597998
- Update nodedev scsi_host data before use
- Resolves: rhbz#600048
- Display wireless devices in nodedev list
- Resolves: rhbz#604811
- Show pool and domain persistence
- Resolves: rhbz#603696
- Fix cleanup after failing to hotplug a PCI device
- Resolves: rhbz#605168
- Add '-nodefconfig' command line arg to QEMU
- Resolves: rhbz#602778
- Switch to private redhat namespace for QMP I/O error reason
- Resolves: rhbz#586353
- Improve error messages for missing drivers & unsupported functions
- Resolves: rhbz#595609
- macvtap: get interface index if not provided
- Resolves: rhbz#605187
- Fix leaks in remote code
- Resolves: rhbz#603442
- Add an optional switch --uuid to the virsh vol-pool command
- Resolves: rhbz#604929
- Change per-connection hashes to be indexed by UUIDs
- Resolves: rhbz#603494
- Run virsh from libvirt-guests script with /dev/null on stdin
- Resolves: rhbz#606314
- Increase dd block size to speed up domain save
- Resolves: rhbz#601775
- Fix reference counting bugs on qemu monitor
- Resolves: rhbz#602660
- Add missing action parameter in IO error callback
- Resolves: rhbz#607157

* Wed Jun 16 2010 Dave Allan <dallan@redhat.com> - 0.8.1-9
- Touch libvirt-guests lockfile
- Resolves: rhbz#566647
- Add qemu.conf option for clearing capabilities
- Resolves: rhbz#593903
- Add support for launching guest in paused state
- Resolves: rhbz#589465
- Add virsh vol-pool command
- Resolves: rhbz#602217
- Add vol commands to virsh man page
- Resolves: rhbz#600640
- Remove bogus migrate error messages
- Resolves: rhbz#601575


* Thu Jun 10 2010 Dave Allan <dallan@redhat.com> - 0.8.1-8
- Ensure virtio serial has stable addressing
- Resolves: rhbz#586665
- SELinux socket labelling on QEMU monitor socket for MLS
- Resolves: rhbz#593739
- Fix enumeration of partitions in disks with a trailing digit in path
- Resolves: rhbz#593785
- Enable probing of VPC disk format type
- Resolves: rhbz#597981
- Delete UNIX domain sockets upon daemon shutdown
- Resolves: rhbz#598163
- Fix Migration failure 'canonical hostname pointed to localhost'
- Resolves: rhbz#589864
- Fix up the python bindings for snapshotting
- Resolves: rhbz#591839
- Sanitize pool target paths
- Resolves: rhbz#593565
- Prevent host network conflicts
- Resolves: rhbz#594494
- Support 802.1Qbg and bh (vnlink/VEPA) (refresh)
- Resolves: rhbz#590110

* Wed May 26 2010 Dave Allan <dallan@redhat.com> - 0.8.1-7
- Fix sign extension error in libvirt's parsing of qemu options
- Resolves: rhbz#592070
- Graceful shutdown/suspend of libvirt guests on host shutdown
- Resolves: rhbz#566647
- Fix pci device hotplug
- Resolves: rhbz#572867
- Support 802.1Qbg and bh
- Resolves: rhbz#532760, rhbz#570949, rhbz#590110, rhbz#570923

* Wed May 19 2010 Dave Allan <dallan@redhat.com> - 0.8.1-6
- Support seamless migration of SPICE graphics clients (refresh)
- Resolves: rhbz#591551
- Fix swapping of PCI vendor & product names in udev backend
- Resolves: rhbz#578419
- Fix cgroup setup code to cope with root squashing NFS
- Resolves: rhbz#593193
- Fix startup error reporting race
- Resolves: rhbz#591272

* Tue May 18 2010 Dave Allan <dallan@redhat.com> - 0.8.1-5
- Don't reset user/group/security label for any files on shared filesystems
- Resolves: rhbz#578889
- Make saved state labelling ignore the dynamic_ownership parameter
- Resolves: rhbz#588562
- Fix & protect against NULL pointer dereference in monitor code
- Resolves: rhbz#591076
- Fix virFileResolveLink return value
- Resolves: rhbz#591363
- Add support for SSE4.1 and SSE4.2 CPU features
- Resolves: rhbz#592977

* Wed May 14 2010 Dave Allan <dallan@redhat.com> - 0.8.1-4
- query QEMU to get the actual allocated extent of a block device
- Resolves: rhbz#526289

* Wed May 12 2010 Daniel Veillard <veillard@redhat.com> - 0.8.1-3
- missing python bindings due to older XML api
- Resolves: rhbz#589453
- Fix two possible crashes in JSON event dispatch
- Resolves: rhbz#586353
- Fix handling of disk backing stores with cgroups
- Resolves: rhbz#581476
- virsh schedinfo --set error handling on unknow parameters
- Resolves: rhbz#586632
- Apply extra patches for nwfilter
- Resolves: rhbz#588554
- Fix hang during concurrent guest migrations
- Resolves: rhbz#582278

* Fri May  7 2010 Daniel Veillard <veillard@redhat.com> - 0.8.1-2
- Don't wipe generated iface target in active domains (588046)
- Fix LXC domain lookup and error handling (586361)
- Fix a protocol breakage introduced in libvirt-0.8.0
- Add support for nic hotplug in QEMU/KVM (589978)
- Seemless migration of spice graphics clients (589989)
- fix build with ESX support
- Resolves: rhbz#581966
- fix multilib problem (587231)

* Fri Apr 30 2010 Daniel Veillard <veillard@redhat.com> - 0.8.1-1
- Rebase to upstream 0.8.1
- Resolves: rhbz#558761

* Fri Apr 23 2010 Daniel Veillard <veillard@redhat.com> - 0.8.0-4
- Fix libvirtd startup when avahi failed to look up local host name
- CPU selection fixes
- Resolves: rhbz#581627
- fix migration poll value
- Resolves: rhbz#584928
- crash dump job caused libvirt hang
- Resolves: rhbz#580853
- Fix initial VCPU pinning in qemu driver
- Resolves: rhbz#578434
- fix cpu hotplug command names

* Tue Apr 20 2010 Daniel Veillard <veillard@redhat.com> - 0.8.0-3
- Build ESX support in
- Resolves: rhbz#581966
- a batch of network filter fixes, IBM request and upstream fixes
- Resolves: rhbz#579993
- couple of patchs to fix device handling with QMP
- Related: rhbz#563189
- fix python binding for snapshotting
- spec file fixes for nwfiler build and RHEL-5 virt-v2v specific rebuild

* Tue Apr 13 2010 Daniel P. Berrange <berrange@redhat.com> - 0.8.0-2
- Refresh SPICE patches to fix test failures
- Related: rhbz#515265, rhbz#524623, rhbz#573382
- Enable test suite during build, disabling tests that don't work in mock
- Related: rhbz#558761

* Mon Apr 12 2010 Daniel Veillard <veillard@redhat.com> - 0.8.0-1
- official 0.8.0 upstream release
- Resolves: rhbz#558761
- new patch set of patches for RHEL-6 SPICE and addons
- Enable QMP/ JSON mode in the QEMU monitor
- Resolves: rhbz#563189
- Support configuration of SPICE as a graphics protocol
- Resolves: rhbz#515265
- vnc (and spice) ticketing
- Resolves: rhbz#524623
- enable spice tls encryption in domainXML, and which channels are encrypted
- Resolves: rhbz#573382
- notification of VNC/SPICE client disconnect/connect events
- Resolves: rhbz#515268

* Wed Apr  7 2010 Daniel Veillard <veillard@redhat.com> - 0.8.0-0.pre20100407
- preview #4 for 0.8.0 rebase
- snapshot API
- domain with disk on root-squashing nfs and security driver mismatch
- Resolves: rhbz#578630
- Fail to read xml when restore domain
- Resolves: rhbz#577719
- loop "virsh cd" in virsh interactive terminal generate unknown error
- Resolves: rhbz#572380
- support setting qemu's -drive werror=stop/enospc with configuration
- Resolves: rhbz#526231

* Mon Mar 30 2010 Daniel Veillard <veillard@redhat.com> - 0.7.8-0.pre20100330
- preview #3 for 0.7.8 rebase
- kvm hpet support
- Resolves: rhbz#576973
- hook scripts support
- Resolves: rhbz#569965
- Need to add time keeping abstraction
- Resolves: rhbz#557285
- notification of guest reboot
- Resolves: rhbz#527572
- Ability to preserve RTC clock adjustments across guest reboots
- Resolves: rhbz#515273
- Notifications of guest stopping due to disk I/O errors
- Resolves: rhbz#515270
- VNC ticketing support (524623) spice still needed
- VNC client disconnect/connect events (515268) spice still needed

* Mon Mar 22 2010 Daniel Veillard <veillard@redhat.com> - 0.7.8-0.pre20100322
- preview #2 for 0.7.8 rebase
- migration max downtime API
- Resolves: rhbz#561935
- allow suspend during migration
- Resolves: rhbz#561934
- support vhost net mode at qemu startup for net devices
- Resolves: rhbz#540391
- read-only device access support for qemu
- Resolves: rhbz#556769
- LSB compliance of libvirtd init script
- Resolves: rhbz#538701
- No domain vcpu information output when using JSON monitor
- Resolves: rhbz#572051
- "qemudDomainSetMaxMemory" does not work and should be removed
- Resolves: rhbz#572146
- after setvcpus, any virsh command will be hung
- Resolves: rhbz#572193
- virsh interactive terminal crash or hung
- Resolves: rhbz#572376
- virsh hangs after core dump
- Resolves: rhbz#572544
- Fix very slow file allocation on ext3

* Fri Mar 12 2010 Daniel Veillard <veillard@redhat.com> - 0.7.8-0.pre20100312
- preview for 0.7.8 rebase
- Extra non upstream basic patch for spice and XQL
- Resolves: rhbz#515264
- Resolves: rhbz#515265
- connected virsh dies with a SIGPIPE after libvirtd restart
- Resolves: rhbz#526656
- error when running logrotate on s/390x arch
- Resolves: rhbz#547514

* Fri Mar  5 2010 Daniel Veillard <veillard@redhat.com> - 0.7.7-1
- macvtap support (rhbz#553348)
- async job handling (rhbz #515278)
- virtio channel (rhbz#515281)
- computing baseline CPU
- virDomain{Attach,Detach}DeviceFlags
- Improve libvirt error reporting for failed migrations (rhbz#528793)
- qemu driver support CPU hotplug (rhbz#533138)
- wrong (octal) device number for attaching USB devices (rhbz#549840)
- cannot save domain into root_squashing nfs export (rhbz#558763)
- assorted bug fixes and lots of cleanups

* Wed Mar  3 2010 Daniel P. Berrange <berrange@redhat.com> - 0.7.6-4
- Fix balloon parameter name handling in JSON mode (rhbz #566261)

* Fri Feb 26 2010 Daniel P. Berrange <berrange@redhat.com> - 0.7.6-3
- Fix balloon units handling in JSON mode (rhbz #566261)
- Invoke qmp_capabilities at monitor startup (rhbz #563189)

* Wed Feb 10 2010 Daniel Veillard <veillard@redhat.com> - 0.7.6-2
- enable JSON interface, desactivated by default in 0.7.6
- Resolves: rhbz#563189
- make sure cgroups are installed and that cgconfig service is on
- Resolves: rhbz#531263

* Wed Feb  3 2010 Daniel Veillard <veillard@redhat.com> - 0.7.6-1
- upstream release of 0.7.6
- Use QEmu new device adressing when possible
- Implement CPU topology support for QEMU driver
- Implement SCSI controller hotplug/unplug for QEMU
- Implement support for multi IQN
- a lot of fixes and improvements
- Resolves: rhbz#558761

* Fri Jan 22 2010 Daniel Veillard <veillard@redhat.com> - 0.7.6-0.pre20100121
- push updated prerelease version of 0.7.6 for testing in Beta1
- Resolves: rhbz#515213

* Thu Jan 21 2010 Daniel Veillard <veillard@redhat.com> - 0.7.6-0.pre20100121
- Push a prerelease version of 0.7.6 for testing in Beta1
- Allow specifying -cpu model/flags for qemu
- Resolves: rhbz#515213
- Add async qemu machine protocol to libvirt based on JSON QEmu API
- Resolves: rhbz#518701
- Allow for static PCI address assignment to all devices
- Resolves: rhbz#481924
- expose qemu's -fda fat:floppy feature (525074)
- configuration of virtual CPU topology (sockets, threads, cores) (538015)
- rewrite file chown'ing code to use security driver framework (547545 )
- cannot create a headless KVM virtual machine (548127)
- Improve virsh schedular parameters documentation (548485)
- Fail to delete a inactive pool using command "virsh pool-delete" (530985)
- virsh man page updation for using container (lxc:///) (528709)
- Command 'virsh vcpuinfo' returns libvirt error in RHEL6 with KVM (522829)
- Expose information about host CPU flags in capabilities (518062)

* Fri Jan 15 2010 Daniel P. Berrange <berrange@redhat.com> - 0.7.5-2
- Rebuild for libparted soname change (rhbz #555741)

* Wed Dec 23 2009 Daniel Veillard <veillard@redhat.com> - 0.7.5-1
- Add new API virDomainMemoryStats
- Public API and domain extension for CPU flags
- vbox: Add support for version 3.1
- Support QEMU's virtual FAT block device driver
- a lot of fixes

* Fri Nov 20 2009 Daniel Veillard <veillard@redhat.com> - 0.7.4-1
- upstream release of 0.7.4
- udev node device backend
- API to check object properties
- better QEmu monitor processing
- MAC address based port filtering for qemu
- support IPv6 and multiple addresses per interfaces
- a lot of fixes

* Thu Nov 19 2009 Daniel P. Berrange <berrange@redhat.com> - 0.7.2-6
- Really fix restore file labelling this time

* Wed Nov 11 2009 Daniel P. Berrange <berrange@redhat.com> - 0.7.2-5
- Disable numactl on s390[x]. Again.

* Wed Nov 11 2009 Daniel P. Berrange <berrange@redhat.com> - 0.7.2-4
- Fix QEMU save/restore permissions / labelling

* Thu Oct 29 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.2-3
- Avoid compressing small log files (#531030)

* Thu Oct 29 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.2-2
- Make libvirt-devel require libvirt-client, not libvirt
- Fix qemu machine types handling

* Wed Oct 14 2009 Daniel Veillard <veillard@redhat.com> - 0.7.2-1
- Upstream release of 0.7.2
- Allow to define ESX domains
- Allows suspend and resulme of LXC domains
- API for data streams
- many bug fixes

* Tue Oct 13 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.1-12
- Fix restore of qemu guest using raw save format (#523158)

* Fri Oct  9 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.1-11
- Fix libvirtd memory leak during error reply sending (#528162)
- Add several PCI hot-unplug typo fixes from upstream

* Tue Oct  6 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.1-10
- Create /var/log/libvirt/{lxc,uml} dirs for logrotate
- Make libvirt-python dependon on libvirt-client
- Sync misc minor changes from upstream spec

* Tue Oct  6 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.1-9
- Change logrotate config to weekly (#526769)

* Thu Oct  1 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.1-8
- Disable sound backend, even when selinux is disabled (#524499)
- Re-label qcow2 backing files (#497131)

* Wed Sep 30 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.1-7
- Fix USB device passthrough (#522683)

* Mon Sep 21 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.7.1-6
- rebuild for libssh2 1.2

* Mon Sep 21 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.1-5
- Don't set a bogus error in virDrvSupportsFeature()
- Fix raw save format

* Thu Sep 17 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.1-4
- A couple of hot-unplug memory handling fixes (#523953)

* Thu Sep 17 2009 Daniel Veillard <veillard@redhat.com> - 0.7.1-3
- disable numactl on s390[x]

* Thu Sep 17 2009 Daniel Veillard <veillard@redhat.com> - 0.7.1-2
- revamp of spec file for modularity and RHELs

* Tue Sep 15 2009 Daniel Veillard <veillard@redhat.com> - 0.7.1-1
- Upstream release of 0.7.1
- ESX, VBox driver updates
- mutipath support
- support for encrypted (qcow) volume
- compressed save image format for Qemu/KVM
- QEmu host PCI device hotplug support
- configuration of huge pages in guests
- a lot of fixes

* Mon Sep 14 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.1-0.2.gitfac3f4c
- Update to newer snapshot of 0.7.1
- Stop libvirt using untrusted 'info vcpus' PID data (#520864)
- Support relabelling of USB and PCI devices
- Enable multipath storage support
- Restart libvirtd upon RPM upgrade

* Sun Sep  6 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.1-0.1.gitg3ef2e05
- Update to pre-release git snapshot of 0.7.1
- Drop upstreamed patches

* Wed Aug 19 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.0-6
- Fix migration completion with newer versions of qemu (#516187)

* Wed Aug 19 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.0-5
- Add PCI host device hotplug support
- Allow PCI bus reset to reset other devices (#499678)
- Fix stupid PCI reset error message (bug #499678)
- Allow PM reset on multi-function PCI devices (bug #515689)
- Re-attach PCI host devices after guest shuts down (bug #499561)
- Fix list corruption after disk hot-unplug
- Fix minor 'virsh nodedev-list --tree' annoyance

* Thu Aug 13 2009 Daniel P. Berrange <berrange@redhat.com> - 0.7.0-4
- Rewrite policykit support (rhbz #499970)
- Log and ignore NUMA topology problems (rhbz #506590)

* Mon Aug 10 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.0-3
- Don't fail to start network if ipv6 modules is not loaded (#516497)

* Thu Aug  6 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.0-2
- Make sure qemu can access kernel/initrd (bug #516034)
- Set perms on /var/lib/libvirt/boot to 0711 (bug #516034)

* Wed Aug  5 2009 Daniel Veillard <veillard@redhat.com> - 0.7.0-1
- ESX, VBox3, Power Hypervisor drivers
- new net filesystem glusterfs
- Storage cloning for LVM and Disk backends
- interface implementation based on netcf
- Support cgroups in QEMU driver
- QEmu hotplug NIC support
- a lot of fixes

* Fri Jul  3 2009 Daniel Veillard <veillard@redhat.com> - 0.6.5-1
- release of 0.6.5

* Fri May 29 2009 Daniel Veillard <veillard@redhat.com> - 0.6.4-1
- release of 0.6.4
- various new APIs

* Fri Apr 24 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-1
- release of 0.6.3
- VirtualBox driver

* Fri Apr  3 2009 Daniel Veillard <veillard@redhat.com> - 0.6.2-1
- release of 0.6.2

* Fri Mar  4 2009 Daniel Veillard <veillard@redhat.com> - 0.6.1-1
- release of 0.6.1

* Sat Jan 31 2009 Daniel Veillard <veillard@redhat.com> - 0.6.0-1
- release of 0.6.0

* Tue Nov 25 2008 Daniel Veillard <veillard@redhat.com> - 0.5.0-1
- release of 0.5.0

* Tue Sep 23 2008 Daniel Veillard <veillard@redhat.com> - 0.4.6-1
- release of 0.4.6

* Mon Sep  8 2008 Daniel Veillard <veillard@redhat.com> - 0.4.5-1
- release of 0.4.5

* Wed Jun 25 2008 Daniel Veillard <veillard@redhat.com> - 0.4.4-1
- release of 0.4.4
- mostly a few bug fixes from 0.4.3

* Thu Jun 12 2008 Daniel Veillard <veillard@redhat.com> - 0.4.3-1
- release of 0.4.3
- lots of bug fixes and small improvements

* Tue Apr  8 2008 Daniel Veillard <veillard@redhat.com> - 0.4.2-1
- release of 0.4.2
- lots of bug fixes and small improvements

* Mon Mar  3 2008 Daniel Veillard <veillard@redhat.com> - 0.4.1-1
- Release of 0.4.1
- Storage APIs
- xenner support
- lots of assorted improvements, bugfixes and cleanups
- documentation and localization improvements

* Tue Dec 18 2007 Daniel Veillard <veillard@redhat.com> - 0.4.0-1
- Release of 0.4.0
- SASL based authentication
- PolicyKit authentication
- improved NUMA and statistics support
- lots of assorted improvements, bugfixes and cleanups
- documentation and localization improvements

* Sun Sep 30 2007 Daniel Veillard <veillard@redhat.com> - 0.3.3-1
- Release of 0.3.3
- Avahi support
- NUMA support
- lots of assorted improvements, bugfixes and cleanups
- documentation and localization improvements

* Tue Aug 21 2007 Daniel Veillard <veillard@redhat.com> - 0.3.2-1
- Release of 0.3.2
- API for domains migration
- APIs for collecting statistics on disks and interfaces
- lots of assorted bugfixes and cleanups
- documentation and localization improvements

* Tue Jul 24 2007 Daniel Veillard <veillard@redhat.com> - 0.3.1-1
- Release of 0.3.1
- localtime clock support
- PS/2 and USB input devices
- lots of assorted bugfixes and cleanups
- documentation and localization improvements

* Mon Jul  9 2007 Daniel Veillard <veillard@redhat.com> - 0.3.0-1
- Release of 0.3.0
- Secure remote access support
- unification of daemons
- lots of assorted bugfixes and cleanups
- documentation and localization improvements

* Fri Jun  8 2007 Daniel Veillard <veillard@redhat.com> - 0.2.3-1
- Release of 0.2.3
- lot of assorted bugfixes and cleanups
- support for Xen-3.1
- new scheduler API

* Tue Apr 17 2007 Daniel Veillard <veillard@redhat.com> - 0.2.2-1
- Release of 0.2.2
- lot of assorted bugfixes and cleanups
- preparing for Xen-3.0.5

* Thu Mar 22 2007 Jeremy Katz <katzj@redhat.com> - 0.2.1-2.fc7
- don't require xen; we don't need the daemon and can control non-xen now
- fix scriptlet error (need to own more directories)
- update description text

* Fri Mar 16 2007 Daniel Veillard <veillard@redhat.com> - 0.2.1-1
- Release of 0.2.1
- lot of bug and portability fixes
- Add support for network autostart and init scripts
- New API to detect the virtualization capabilities of a host
- Documentation updates

* Fri Feb 23 2007 Daniel P. Berrange <berrange@redhat.com> - 0.2.0-4.fc7
- Fix loading of guest & network configs

* Fri Feb 16 2007 Daniel P. Berrange <berrange@redhat.com> - 0.2.0-3.fc7
- Disable kqemu support since its not in Fedora qemu binary
- Fix for -vnc arg syntax change in 0.9.0  QEMU

* Thu Feb 15 2007 Daniel P. Berrange <berrange@redhat.com> - 0.2.0-2.fc7
- Fixed path to qemu daemon for autostart
- Fixed generation of <features> block in XML
- Pre-create config directory at startup

* Wed Feb 14 2007 Daniel Veillard <veillard@redhat.com> 0.2.0-1.fc7
- support for KVM and QEmu
- support for network configuration
- assorted fixes

* Mon Jan 22 2007 Daniel Veillard <veillard@redhat.com> 0.1.11-1.fc7
- finish inactive Xen domains support
- memory leak fix
- RelaxNG schemas for XML configs

* Wed Dec 20 2006 Daniel Veillard <veillard@redhat.com> 0.1.10-1.fc7
- support for inactive Xen domains
- improved support for Xen display and vnc
- a few bug fixes
- localization updates

* Thu Dec  7 2006 Jeremy Katz <katzj@redhat.com> - 0.1.9-2
- rebuild against python 2.5

* Wed Nov 29 2006 Daniel Veillard <veillard@redhat.com> 0.1.9-1
- better error reporting
- python bindings fixes and extensions
- add support for shareable drives
- add support for non-bridge style networking
- hot plug device support
- added support for inactive domains
- API to dump core of domains
- various bug fixes, cleanups and improvements
- updated the localization

* Tue Nov  7 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-3
- it's pkgconfig not pgkconfig !

* Mon Nov  6 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-2
- fixing spec file, added %dist, -devel requires pkgconfig and xen-devel
- Resolves: rhbz#202320

* Mon Oct 16 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-1
- fix missing page size detection code for ia64
- fix mlock size when getting domain info list from hypervisor
- vcpu number initialization
- don't label crashed domains as shut off
- fix virsh man page
- blktapdd support for alternate drivers like blktap
- memory leak fixes (xend interface and XML parsing)
- compile fix
- mlock/munlock size fixes

* Fri Sep 22 2006 Daniel Veillard <veillard@redhat.com> 0.1.7-1
- Fix bug when running against xen-3.0.3 hypercalls
- Fix memory bug when getting vcpus info from xend

* Fri Sep 22 2006 Daniel Veillard <veillard@redhat.com> 0.1.6-1
- Support for localization
- Support for new Xen-3.0.3 cdrom and disk configuration
- Support for setting VNC port
- Fix bug when running against xen-3.0.2 hypercalls
- Fix reconnection problem when talking directly to http xend

* Tue Sep  5 2006 Jeremy Katz <katzj@redhat.com> - 0.1.5-3
- patch from danpb to support new-format cd devices for HVM guests

* Tue Sep  5 2006 Daniel Veillard <veillard@redhat.com> 0.1.5-2
- reactivating ia64 support

* Tue Sep  5 2006 Daniel Veillard <veillard@redhat.com> 0.1.5-1
- new release
- bug fixes
- support for new hypervisor calls
- early code for config files and defined domains

* Mon Sep  4 2006 Daniel Berrange <berrange@redhat.com> - 0.1.4-5
- add patch to address dom0_ops API breakage in Xen 3.0.3 tree

* Mon Aug 28 2006 Jeremy Katz <katzj@redhat.com> - 0.1.4-4
- add patch to support paravirt framebuffer in Xen

* Mon Aug 21 2006 Daniel Veillard <veillard@redhat.com> 0.1.4-3
- another patch to fix network handling in non-HVM guests

* Thu Aug 17 2006 Daniel Veillard <veillard@redhat.com> 0.1.4-2
- patch to fix virParseUUID()

* Wed Aug 16 2006 Daniel Veillard <veillard@redhat.com> 0.1.4-1
- vCPUs and affinity support
- more complete XML, console and boot options
- specific features support
- enforced read-only connections
- various improvements, bug fixes

* Wed Aug  2 2006 Jeremy Katz <katzj@redhat.com> - 0.1.3-6
- add patch from pvetere to allow getting uuid from libvirt

* Wed Aug  2 2006 Jeremy Katz <katzj@redhat.com> - 0.1.3-5
- build on ia64 now

* Thu Jul 27 2006 Jeremy Katz <katzj@redhat.com> - 0.1.3-4
- don't BR xen, we just need xen-devel

* Thu Jul 27 2006 Daniel Veillard <veillard@redhat.com> 0.1.3-3
- need rebuild since libxenstore is now versionned

* Mon Jul 24 2006 Mark McLoughlin <markmc@redhat.com> - 0.1.3-2
- Add BuildRequires: xen-devel

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 0.1.3-1.1
- rebuild

* Tue Jul 11 2006 Daniel Veillard <veillard@redhat.com> 0.1.3-1
- support for HVM Xen guests
- various bugfixes

* Mon Jul  3 2006 Daniel Veillard <veillard@redhat.com> 0.1.2-1
- added a proxy mechanism for read only access using httpu
- fixed header includes paths

* Wed Jun 21 2006 Daniel Veillard <veillard@redhat.com> 0.1.1-1
- extend and cleanup the driver infrastructure and code
- python examples
- extend uuid support
- bug fixes, buffer handling cleanups
- support for new Xen hypervisor API
- test driver for unit testing
- virsh --conect argument

* Mon Apr 10 2006 Daniel Veillard <veillard@redhat.com> 0.1.0-1
- various fixes
- new APIs: for Node information and Reboot
- virsh improvements and extensions
- documentation updates and man page
- enhancement and fixes of the XML description format

* Tue Feb 28 2006 Daniel Veillard <veillard@redhat.com> 0.0.6-1
- added error handling APIs
- small bug fixes
- improve python bindings
- augment documentation and regression tests

* Thu Feb 23 2006 Daniel Veillard <veillard@redhat.com> 0.0.5-1
- new domain creation API
- new UUID based APIs
- more tests, documentation, devhelp
- bug fixes

* Fri Feb 10 2006 Daniel Veillard <veillard@redhat.com> 0.0.4-1
- fixes some problems in 0.0.3 due to the change of names

* Wed Feb  8 2006 Daniel Veillard <veillard@redhat.com> 0.0.3-1
- changed library name to libvirt from libvir, complete and test the python
  bindings

* Sun Jan 29 2006 Daniel Veillard <veillard@redhat.com> 0.0.2-1
- upstream release of 0.0.2, use xend, save and restore added, python bindings
  fixed

* Wed Nov  2 2005 Daniel Veillard <veillard@redhat.com> 0.0.1-1
- created
